@@ -47,9 +47,6 @@
 #include <QtWidgets/qapplication.h>
 #include <QtGui/qpainter.h>
 
-#ifdef Q_WS_X11
-#  include <X11/Xlib.h>
-#endif
 #include <gst/gst.h>
 #include <gst/interfaces/xoverlay.h>
 #include <gst/interfaces/propertyprobe.h>
