@@ -58,8 +58,6 @@
 #include "qsoundsource_p.h"
 #include "qsoundbuffer_p.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QSoundBufferPrivateAL : public QSoundBuffer
@@ -168,6 +166,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
