@@ -46,8 +46,6 @@
 #include <QtQml/qqmlcomponent.h>
 #include <QVector3D>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QDeclarativeAttenuationModel : public QObject, public QQmlParserStatus
@@ -133,6 +131,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
