@@ -50,8 +50,6 @@
 #include <QTimer>
 #include "qaudioengine_p.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QDeclarativeSoundInstance;
@@ -163,6 +161,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
