@@ -53,9 +53,9 @@ QT_USE_NAMESPACE
 /*!
     \qmltype SoundInstance
     \instantiates QDeclarativeSoundInstance
-    \since 1.0
+    \since 5.0
     \brief Play 3d audio content.
-    \inqmlmodule QtAudioEngine 1.0
+    \inqmlmodule QtAudioEngine
     \ingroup multimedia_audioengine
     \inherits Item
     \preliminary
@@ -442,7 +442,7 @@ void QDeclarativeSoundInstance::setVelocity(const QVector3D& velocity)
 /*!
     \qmlproperty vector3d QtAudioEngine1::SoundInstance::gain
 
-    This property holds the gain adjustment which will be used to modulate the audio ouput level
+    This property holds the gain adjustment which will be used to modulate the audio output level
     from this SoundInstance.
 */
 qreal QDeclarativeSoundInstance::gain() const
