@@ -46,8 +46,6 @@
 #include <QObject>
 #include "qsoundsource_p.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QDeclarativeSound;
@@ -134,6 +132,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QSOUNDINSTANCE_P_H
