@@ -45,8 +45,6 @@
 #include <QVector3D>
 #include <QObject>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QSoundBuffer;
@@ -93,6 +91,4 @@ protected:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
