@@ -59,8 +59,6 @@
 
 #include <qmediaplayer.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QTimerEvent;
@@ -259,6 +257,7 @@ private:
     QMediaPlayer::Error m_error;
     QString m_errorString;
     QUrl m_source;
+    QMediaContent m_content;
 
     QScopedPointer<QDeclarativeMediaMetaData> m_metaData;
 
@@ -271,6 +270,4 @@ QT_END_NAMESPACE
 
 QML_DECLARE_TYPE(QT_PREPEND_NAMESPACE(QDeclarativeAudio))
 
-QT_END_HEADER
-
 #endif
