@@ -57,8 +57,6 @@
 #include <qcamera.h>
 #include <qcameraexposure.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QDeclarativeCamera;
@@ -142,6 +140,4 @@ QT_END_NAMESPACE
 
 QML_DECLARE_TYPE(QT_PREPEND_NAMESPACE(QDeclarativeCameraExposure))
 
-QT_END_HEADER
-
 #endif
