@@ -56,8 +56,6 @@
 #include <qcamera.h>
 #include <qcameraexposure.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QDeclarativeCamera;
@@ -91,6 +89,4 @@ QT_END_NAMESPACE
 
 QML_DECLARE_TYPE(QT_PREPEND_NAMESPACE(QDeclarativeCameraFlash))
 
-QT_END_HEADER
-
 #endif
