@@ -55,8 +55,6 @@
 
 #include <QtQuick/qquickimageprovider.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QDeclarativeCameraPreviewProvider : public QQuickImageProvider
@@ -71,6 +69,4 @@ public:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
