@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the plugins of the Qt Toolkit.
@@ -49,7 +49,7 @@ QT_BEGIN_NAMESPACE
 /*!
     \qmltype CameraRecorder
     \instantiates QDeclarativeCameraRecorder
-    \inqmlmodule QtMultimedia 5.0
+    \inqmlmodule QtMultimedia
     \brief Controls video recording with the Camera.
     \ingroup multimedia_qml
     \ingroup camera_qml
@@ -99,7 +99,7 @@ QDeclarativeCameraRecorder::~QDeclarativeCameraRecorder()
 }
 
 /*!
-    \qmlproperty size QtMultimedia5::CameraRecorder::resolution
+    \qmlproperty size QtMultimedia::CameraRecorder::resolution
 
     This property holds the video frame dimensions to be used for video capture.
 */
@@ -109,12 +109,12 @@ QSize QDeclarativeCameraRecorder::captureResolution()
 }
 
 /*!
-    \qmlproperty string QtMultimedia5::CameraRecorder::audioCodec
+    \qmlproperty string QtMultimedia::CameraRecorder::audioCodec
 
     This property holds the audio codec to be used for recording video.
     Typically this is \c aac or \c amr-wb.
 
-    \sa {QtMultimedia5::CameraImageProcessing::whiteBalanceMode}{whileBalanceMode}
+    \sa {QtMultimedia::CameraImageProcessing::whiteBalanceMode}{whileBalanceMode}
 */
 QString QDeclarativeCameraRecorder::audioCodec() const
 {
@@ -122,7 +122,7 @@ QString QDeclarativeCameraRecorder::audioCodec() const
 }
 
 /*!
-    \qmlproperty string QtMultimedia5::CameraRecorder::videoCodec
+    \qmlproperty string QtMultimedia::CameraRecorder::videoCodec
 
     This property holds the video codec to be used for recording video.
     Typically this is \c h264.
@@ -133,7 +133,7 @@ QString QDeclarativeCameraRecorder::videoCodec() const
 }
 
 /*!
-    \qmlproperty string QtMultimedia5::CameraRecorder::mediaContainer
+    \qmlproperty string QtMultimedia::CameraRecorder::mediaContainer
 
     This property holds the media container to be used for recording video.
     Typically this is \c mp4.
@@ -145,6 +145,7 @@ QString QDeclarativeCameraRecorder::mediaContainer() const
 
 void QDeclarativeCameraRecorder::setCaptureResolution(const QSize &resolution)
 {
+    m_videoSettings = m_recorder->videoSettings();
     if (resolution != captureResolution()) {
         m_videoSettings.setResolution(resolution);
         m_recorder->setVideoSettings(m_videoSettings);
@@ -154,6 +155,7 @@ void QDeclarativeCameraRecorder::setCaptureResolution(const QSize &resolution)
 
 void QDeclarativeCameraRecorder::setAudioCodec(const QString &codec)
 {
+    m_audioSettings = m_recorder->audioSettings();
     if (codec != audioCodec()) {
         m_audioSettings.setCodec(codec);
         m_recorder->setAudioSettings(m_audioSettings);
@@ -163,6 +165,7 @@ void QDeclarativeCameraRecorder::setAudioCodec(const QString &codec)
 
 void QDeclarativeCameraRecorder::setVideoCodec(const QString &codec)
 {
+    m_videoSettings = m_recorder->videoSettings();
     if (codec != videoCodec()) {
         m_videoSettings.setCodec(codec);
         m_recorder->setVideoSettings(m_videoSettings);
@@ -180,7 +183,7 @@ void QDeclarativeCameraRecorder::setMediaContainer(const QString &container)
 }
 
 /*!
-    \qmlproperty qreal QtMultimedia5::CameraRecorder::frameRate
+    \qmlproperty qreal QtMultimedia::CameraRecorder::frameRate
 
     This property holds the framerate (in frames per second) to be used for recording video.
 */
@@ -190,7 +193,7 @@ qreal QDeclarativeCameraRecorder::frameRate() const
 }
 
 /*!
-    \qmlproperty int QtMultimedia5::CameraRecorder::videoBitRate
+    \qmlproperty int QtMultimedia::CameraRecorder::videoBitRate
 
     This property holds the bit rate (in bits per second) to be used for recording video.
 */
@@ -200,7 +203,7 @@ int QDeclarativeCameraRecorder::videoBitRate() const
 }
 
 /*!
-    \qmlproperty int QtMultimedia5::CameraRecorder::audioBitRate
+    \qmlproperty int QtMultimedia::CameraRecorder::audioBitRate
 
     This property holds the audio bit rate (in bits per second) to be used for recording video.
 */
@@ -210,7 +213,7 @@ int QDeclarativeCameraRecorder::audioBitRate() const
 }
 
 /*!
-    \qmlproperty int QtMultimedia5::CameraRecorder::audioChannels
+    \qmlproperty int QtMultimedia::CameraRecorder::audioChannels
 
     This property indicates the number of audio channels to be encoded while
     recording video (1 is mono, 2 is stereo).
@@ -221,7 +224,7 @@ int QDeclarativeCameraRecorder::audioChannels() const
 }
 
 /*!
-    \qmlproperty int QtMultimedia5::CameraRecorder::audioSampleRate
+    \qmlproperty int QtMultimedia::CameraRecorder::audioSampleRate
 
     This property holds the sample rate to be used to encode audio while recording video.
 */
@@ -231,7 +234,7 @@ int QDeclarativeCameraRecorder::audioSampleRate() const
 }
 
 /*!
-    \qmlproperty enumeration QtMultimedia5::CameraRecorder::videoEncodingMode
+    \qmlproperty enumeration QtMultimedia::CameraRecorder::videoEncodingMode
 
     This property holds the type of encoding method to be used for recording video.
 
@@ -257,7 +260,7 @@ QDeclarativeCameraRecorder::EncodingMode QDeclarativeCameraRecorder::videoEncodi
 }
 
 /*!
-    \qmlproperty enumeration QtMultimedia5::CameraRecorder::audioEncodingMode
+    \qmlproperty enumeration QtMultimedia::CameraRecorder::audioEncodingMode
 
     The type of encoding method to use when recording audio.
 
@@ -281,6 +284,7 @@ QDeclarativeCameraRecorder::EncodingMode QDeclarativeCameraRecorder::audioEncodi
 
 void QDeclarativeCameraRecorder::setFrameRate(qreal frameRate)
 {
+    m_videoSettings = m_recorder->videoSettings();
     if (!qFuzzyCompare(m_videoSettings.frameRate(),frameRate)) {
         m_videoSettings.setFrameRate(frameRate);
         m_recorder->setVideoSettings(m_videoSettings);
@@ -290,6 +294,7 @@ void QDeclarativeCameraRecorder::setFrameRate(qreal frameRate)
 
 void QDeclarativeCameraRecorder::setVideoBitRate(int rate)
 {
+    m_videoSettings = m_recorder->videoSettings();
     if (m_videoSettings.bitRate() != rate) {
         m_videoSettings.setBitRate(rate);
         m_recorder->setVideoSettings(m_videoSettings);
@@ -299,6 +304,7 @@ void QDeclarativeCameraRecorder::setVideoBitRate(int rate)
 
 void QDeclarativeCameraRecorder::setAudioBitRate(int rate)
 {
+    m_audioSettings = m_recorder->audioSettings();
     if (m_audioSettings.bitRate() != rate) {
         m_audioSettings.setBitRate(rate);
         m_recorder->setAudioSettings(m_audioSettings);
@@ -308,6 +314,7 @@ void QDeclarativeCameraRecorder::setAudioBitRate(int rate)
 
 void QDeclarativeCameraRecorder::setAudioChannels(int channels)
 {
+    m_audioSettings = m_recorder->audioSettings();
     if (m_audioSettings.channelCount() != channels) {
         m_audioSettings.setChannelCount(channels);
         m_recorder->setAudioSettings(m_audioSettings);
@@ -317,6 +324,7 @@ void QDeclarativeCameraRecorder::setAudioChannels(int channels)
 
 void QDeclarativeCameraRecorder::setAudioSampleRate(int rate)
 {
+    m_audioSettings = m_recorder->audioSettings();
     if (m_audioSettings.sampleRate() != rate) {
         m_audioSettings.setSampleRate(rate);
         m_recorder->setAudioSettings(m_audioSettings);
@@ -326,6 +334,7 @@ void QDeclarativeCameraRecorder::setAudioSampleRate(int rate)
 
 void QDeclarativeCameraRecorder::setAudioEncodingMode(QDeclarativeCameraRecorder::EncodingMode encodingMode)
 {
+    m_audioSettings = m_recorder->audioSettings();
     if (m_audioSettings.encodingMode() != QMultimedia::EncodingMode(encodingMode)) {
         m_audioSettings.setEncodingMode(QMultimedia::EncodingMode(encodingMode));
         m_recorder->setAudioSettings(m_audioSettings);
@@ -335,6 +344,7 @@ void QDeclarativeCameraRecorder::setAudioEncodingMode(QDeclarativeCameraRecorder
 
 void QDeclarativeCameraRecorder::setVideoEncodingMode(QDeclarativeCameraRecorder::EncodingMode encodingMode)
 {
+    m_videoSettings = m_recorder->videoSettings();
     if (m_videoSettings.encodingMode() != QMultimedia::EncodingMode(encodingMode)) {
         m_videoSettings.setEncodingMode(QMultimedia::EncodingMode(encodingMode));
         m_recorder->setVideoSettings(m_videoSettings);
@@ -343,7 +353,7 @@ void QDeclarativeCameraRecorder::setVideoEncodingMode(QDeclarativeCameraRecorder
 }
 
 /*!
-    \qmlproperty enumeration QtMultimedia5::CameraRecorder::errorCode
+    \qmlproperty enumeration QtMultimedia::CameraRecorder::errorCode
 
     This property holds the last error code.
 
@@ -369,7 +379,7 @@ QDeclarativeCameraRecorder::Error QDeclarativeCameraRecorder::errorCode() const
 }
 
 /*!
-    \qmlproperty string QtMultimedia5::CameraRecorder::errorString
+    \qmlproperty string QtMultimedia::CameraRecorder::errorString
 
     This property holds the description of the last error.
 */
@@ -379,7 +389,7 @@ QString QDeclarativeCameraRecorder::errorString() const
 }
 
 /*!
-    \qmlproperty enumeration QtMultimedia5::CameraRecorder::recorderState
+    \qmlproperty enumeration QtMultimedia::CameraRecorder::recorderState
 
     This property holds the current state of the camera recorder object.
 
@@ -407,7 +417,7 @@ QDeclarativeCameraRecorder::RecorderState QDeclarativeCameraRecorder::recorderSt
 
 
 /*!
-    \qmlproperty enumeration QtMultimedia5::CameraRecorder::recorderStatus
+    \qmlproperty enumeration QtMultimedia::CameraRecorder::recorderStatus
 
     This property holds the current status of media recording.
 
@@ -438,7 +448,7 @@ QDeclarativeCameraRecorder::RecorderStatus QDeclarativeCameraRecorder::recorderS
 }
 
 /*!
-    \qmlmethod QtMultimedia5::CameraRecorder::record()
+    \qmlmethod QtMultimedia::CameraRecorder::record()
 
     Starts recording.
 */
@@ -448,7 +458,7 @@ void QDeclarativeCameraRecorder::record()
 }
 
 /*!
-    \qmlmethod QtMultimedia5::CameraRecorder::stop()
+    \qmlmethod QtMultimedia::CameraRecorder::stop()
 
     Stops recording.
 */
@@ -478,7 +488,7 @@ void QDeclarativeCameraRecorder::setRecorderState(QDeclarativeCameraRecorder::Re
     the recorder uses the system-specific place and file naming scheme.
 */
 /*!
-    \qmlproperty string QtMultimedia5::CameraRecorder::outputLocation
+    \qmlproperty string QtMultimedia::CameraRecorder::outputLocation
 
     This property holds the destination location of the media content. If the location is empty,
     the recorder uses the system-specific place and file naming scheme.
@@ -496,7 +506,7 @@ QString QDeclarativeCameraRecorder::outputLocation() const
     new location is set or new recording starts.
 */
 /*!
-    \qmlproperty string QtMultimedia5::CameraRecorder::actualLocation
+    \qmlproperty string QtMultimedia::CameraRecorder::actualLocation
 
     This property holds the actual location of the last saved media content. The actual location is
     usually available after the recording starts, and reset when new location is set or the new recording starts.
@@ -520,7 +530,7 @@ void QDeclarativeCameraRecorder::setOutputLocation(const QString &location)
     This property holds the duration (in miliseconds) of the last recording.
 */
 /*!
-    \qmlproperty int QtMultimedia5::CameraRecorder::duration
+    \qmlproperty int QtMultimedia::CameraRecorder::duration
 
    This property holds the duration (in miliseconds) of the last recording.
 */
@@ -535,7 +545,7 @@ qint64 QDeclarativeCameraRecorder::duration() const
     recording.
 */
 /*!
-    \qmlproperty bool QtMultimedia5::CameraRecorder::muted
+    \qmlproperty bool QtMultimedia::CameraRecorder::muted
 
     This property indicates whether the audio input is muted during recording.
 */
@@ -550,7 +560,7 @@ void QDeclarativeCameraRecorder::setMuted(bool muted)
 }
 
 /*!
-    \qmlmethod QtMultimedia5::CameraRecorder::setMetadata(key, value)
+    \qmlmethod QtMultimedia::CameraRecorder::setMetadata(key, value)
 
     Sets metadata for the next video to be recorder, with
     the given \a key being associated with \a value.
