@@ -54,10 +54,9 @@
 //
 
 #include <QtQml/qqml.h>
+#include <QtMultimedia/qmediametadata.h>
 #include "qmediaobject.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QDeclarativeMediaMetaData : public QObject
@@ -179,6 +178,4 @@ QT_END_NAMESPACE
 
 QML_DECLARE_TYPE(QT_PREPEND_NAMESPACE(QDeclarativeMediaMetaData))
 
-QT_END_HEADER
-
 #endif
