@@ -56,8 +56,6 @@
 #include <qradiotuner.h>
 #include <QtQml/qqml.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QDeclarativeRadioData;
@@ -202,6 +200,4 @@ QT_END_NAMESPACE
 
 QML_DECLARE_TYPE(QT_PREPEND_NAMESPACE(QDeclarativeRadio))
 
-QT_END_HEADER
-
 #endif // QDECLARATIVERADIO_P_H
