@@ -48,8 +48,6 @@
 
 #include <QtCore/qmetatype.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 //QTM_SYNC_HEADER_EXPORT QAudio
@@ -75,6 +73,4 @@ Q_DECLARE_METATYPE(QAudio::Error)
 Q_DECLARE_METATYPE(QAudio::State)
 Q_DECLARE_METATYPE(QAudio::Mode)
 
-QT_END_HEADER
-
 #endif // QAUDIO_H
