@@ -50,8 +50,6 @@
 #include <QtMultimedia/qaudio.h>
 #include <QtMultimedia/qaudioformat.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QAbstractAudioBuffer;
@@ -152,6 +150,4 @@ QT_END_NAMESPACE
 
 Q_DECLARE_METATYPE(QAudioBuffer)
 
-QT_END_HEADER
-
 #endif // QAUDIOBUFFER_H
