@@ -151,18 +151,18 @@ QAudioInput::~QAudioInput()
 }
 
 /*!
-     Uses the \a device as the QIODevice to transfer data.
-     Passing a QIODevice allows the data to be transferred without any extra code.
-     All that is required is to open the QIODevice.
+    Starts transferring audio data from the system's audio input to the \a device.
+    The \a device must have been opened in the \l{QIODevice::WriteOnly}{WriteOnly},
+    \l{QIODevice::Append}{Append} or \l{QIODevice::ReadWrite}{ReadWrite} modes.
 
-     If able to successfully get audio data from the systems audio device the
-     state() is set to either QAudio::ActiveState or QAudio::IdleState,
-     error() is set to QAudio::NoError and the stateChanged() signal is emitted.
+    If the QAudioInput is able to successfully get audio data, state() returns
+    either QAudio::ActiveState or QAudio::IdleState, error() returns QAudio::NoError
+    and the stateChanged() signal is emitted.
 
-     If a problem occurs during this process the error() is set to QAudio::OpenError,
-     state() is set to QAudio::StoppedState and stateChanged() signal is emitted.
+    If a problem occurs during this process, error() returns QAudio::OpenError,
+    state() returns QAudio::StoppedState and the stateChanged() signal is emitted.
 
-     \sa QIODevice
+    \sa QIODevice
 */
 
 void QAudioInput::start(QIODevice* device)
@@ -171,16 +171,19 @@ void QAudioInput::start(QIODevice* device)
 }
 
 /*!
-    Returns a pointer to the QIODevice being used to handle the data
-    transfer. This QIODevice can be used to read() audio data
-    directly.
+    Returns a pointer to the internal QIODevice being used to transfer data from
+    the system's audio input. The device will already be open and
+    \l{QIODevice::read()}{read()} can read data directly from it.
 
-    If able to access the systems audio device the state() is set to
-    QAudio::IdleState, error() is set to QAudio::NoError
+    \note The pointer will become invalid after the stream is stopped or
+    if you start another stream.
+
+    If the QAudioInput is able to access the system's audio device, state() returns
+    QAudio::IdleState, error() returns QAudio::NoError
     and the stateChanged() signal is emitted.
 
-    If a problem occurs during this process the error() is set to QAudio::OpenError,
-    state() is set to QAudio::StoppedState and stateChanged() signal is emitted.
+    If a problem occurs during this process, error() returns QAudio::OpenError,
+    state() returns QAudio::StoppedState and the stateChanged() signal is emitted.
 
     \sa QIODevice
 */
