@@ -53,8 +53,6 @@
 #include <QtMultimedia/qaudiodeviceinfo.h>
 
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -113,6 +111,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QAUDIOOUTPUT_H
