@@ -45,8 +45,6 @@
 #include <QtMultimedia/qtmultimediadefs.h>
 #include <QtCore/qobject.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QSoundEffect;
@@ -85,7 +83,5 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif // QSOUND_H
