@@ -48,8 +48,6 @@
 #include <QtCore/qstringlist.h>
 
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -132,7 +130,5 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif // QSOUNDEFFECT_H
