@@ -153,13 +153,15 @@ void QWaveDecoder::handleData()
             chunk descriptor;
             peekChunk(&descriptor);
 
-            if (source->bytesAvailable() < qint64(descriptor.size + sizeof(chunk)))
+            quint32 rawChunkSize = descriptor.size + sizeof(chunk);
+            if (source->bytesAvailable() < qint64(rawChunkSize))
                 return;
 
             WAVEHeader wave;
             source->read(reinterpret_cast<char *>(&wave), sizeof(WAVEHeader));
-            if (descriptor.size > sizeof(WAVEHeader))
-                discardBytes(descriptor.size - sizeof(WAVEHeader));
+
+            if (rawChunkSize > sizeof(WAVEHeader))
+                discardBytes(rawChunkSize - sizeof(WAVEHeader));
 
             // Swizzle this
             if (bigEndian) {
@@ -242,16 +244,18 @@ bool QWaveDecoder::enoughDataAvailable()
 bool QWaveDecoder::findChunk(const char *chunkId)
 {
     chunk descriptor;
-    if (!peekChunk(&descriptor))
-        return false;
 
-    if (qstrncmp(descriptor.id, chunkId, 4) == 0)
-        return true;
+    do {
+        if (!peekChunk(&descriptor))
+            return false;
+
+        if (qstrncmp(descriptor.id, chunkId, 4) == 0)
+            return true;
+
+        // It's possible that bytes->available() is less than the chunk size
+        // if it's corrupt.
+        junkToSkip = qint64(sizeof(chunk) + descriptor.size);
 
-    // It's possible that bytes->available() is less than the chunk size
-    // if it's corrupt.
-    junkToSkip = qint64(sizeof(chunk) + descriptor.size);
-    while (source->bytesAvailable() > 0) {
         // Skip the current amount
         if (junkToSkip > 0)
             discardBytes(junkToSkip);
@@ -261,12 +265,7 @@ bool QWaveDecoder::findChunk(const char *chunkId)
         if (junkToSkip > 0)
             return false;
 
-        if (!peekChunk(&descriptor))
-            return false;
-
-        if (qstrncmp(descriptor.id, chunkId, 4) == 0)
-            return true;
-    }
+    } while (source->bytesAvailable() > 0);
 
     return false;
 }
