@@ -57,8 +57,6 @@
 #include <qaudioformat.h>
 
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -134,6 +132,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // WAVEDECODER_H
