@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the Qt Toolkit.
@@ -175,22 +175,15 @@ void QCameraPrivate::_q_error(int error, const QString &errorString)
 
 void QCameraPrivate::setState(QCamera::State newState)
 {
-    Q_Q(QCamera);
-
     unsetError();
 
     if (!control) {
-        _q_error(QCamera::ServiceMissingError, q_ptr->tr("The camera service is missing"));
+        _q_error(QCamera::ServiceMissingError, QCamera::tr("The camera service is missing"));
         return;
     }
 
-    if (state == newState)
-        return;
-
     restartPending = false;
-    state = newState;
-    control->setState(state);
-    emit q->stateChanged(state);
+    control->setState(newState);
 }
 
 void QCameraPrivate::_q_updateState(QCamera::State newState)
@@ -203,7 +196,6 @@ void QCameraPrivate::_q_updateState(QCamera::State newState)
         return;
 
     if (newState != state) {
-        qDebug() << "Camera state changed:" << newState;
         state = newState;
         emit q->stateChanged(state);
     }
