@@ -47,8 +47,6 @@
 #include <QtCore/qlist.h>
 #include <QtCore/qpair.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QStringList;
@@ -85,7 +83,5 @@ Q_MEDIA_DECLARE_CONTROL(QAudioEncoderSettingsControl, QAudioEncoderSettingsContr
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif // QAUDIOENCODERSETTINGSCONTROL_H
