@@ -50,8 +50,6 @@
 #include <QtMultimedia/qcamera.h>
 #include <QtMultimedia/qmediaenumdebug.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 // Required for QDoc workaround
@@ -96,7 +94,5 @@ Q_MEDIA_DECLARE_CONTROL(QCameraFeedbackControl, QCameraFeedbackControl_iid)
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif // QCAMERAFEEDBACKCONTROL_H
