@@ -46,8 +46,6 @@
 
 #include <QtMultimedia/qmediacontrol.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 // Required for QDoc workaround
@@ -81,6 +79,4 @@ Q_MEDIA_DECLARE_CONTROL(QCameraViewfinderSettingsControl, QCameraViewfinderSetti
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QCAMERAVIEWFINDERSETTINGSCONTROL_H
