@@ -56,8 +56,6 @@
 
 #include <qmediacontrol.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -85,7 +83,5 @@ Q_MEDIA_DECLARE_CONTROL(QMediaPlaylistSourceControl, QMediaPlaylistSourceControl
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif // QMEDIAPLAYLISTCONTROL_P_H
