@@ -44,8 +44,6 @@
 
 #include <QtMultimedia/qmediacontrol.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 // Required for QDoc workaround
@@ -83,6 +81,4 @@ Q_MEDIA_DECLARE_CONTROL(QVideoDeviceSelectorControl, QVideoDeviceSelectorControl
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QVIDEODEVICESELECTORCONTROL_H
