@@ -48,8 +48,6 @@
 #include <QtCore/qpair.h>
 #include <QtCore/qsize.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QByteArray;
@@ -89,7 +87,5 @@ Q_MEDIA_DECLARE_CONTROL(QVideoEncoderSettingsControl, QVideoEncoderSettingsContr
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif
