@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the Qt Toolkit.
@@ -864,6 +864,11 @@ void QMediaPlayer::setPlaybackRate(qreal rate)
     Setting the media to a null QMediaContent will cause the player to discard all
     information relating to the current media source and to cease all I/O operations related
     to that media.
+
+    \note This function returns immediately after recording the specified source of the media.
+    It does not wait for the media to finish loading and does not check for errors. Listen for
+    the mediaStatusChanged() and error() signals to be notified when the media is loaded and
+    when an error occurs during loading.
 */
 
 void QMediaPlayer::setMedia(const QMediaContent &media, QIODevice *stream)
@@ -1220,7 +1225,7 @@ QMultimedia::AvailabilityStatus QMediaPlayer::availability() const
     \property QMediaPlayer::volume
     \brief the current playback volume.
 
-    The playback volume is a linear in effect and the value can range from 0 -
+    The playback volume is linear in effect and the value can range from 0 -
     100, values outside this range will be clamped.
 */
 
