@@ -48,8 +48,6 @@
 
 #include <QtNetwork/qnetworkconfiguration.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -226,6 +224,4 @@ Q_MEDIA_ENUM_DEBUG(QMediaPlayer, State)
 Q_MEDIA_ENUM_DEBUG(QMediaPlayer, MediaStatus)
 Q_MEDIA_ENUM_DEBUG(QMediaPlayer, Error)
 
-QT_END_HEADER
-
 #endif  // QMEDIAPLAYER_H
