@@ -60,8 +60,6 @@
 
 #include "qmediacontent.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QString;
@@ -126,7 +124,5 @@ public:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif // QMEDIAPLAYLISTIOPLUGIN_P_H
