@@ -56,8 +56,6 @@
 #include "qmediacontent.h"
 #include "qmediaplaylist.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -120,8 +118,6 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 
 #endif // QMEDIAPLAYLISTSOURCE_P_H
