@@ -49,8 +49,6 @@
 #include <QtCore/qvariant.h>
 
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -79,7 +77,5 @@ template <typename T> const char *qmediacontrol_iid() { return 0; }
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif  // QABSTRACTMEDIACONTROL_H
