@@ -48,8 +48,6 @@
 
 #include <QtMultimedia/qtmultimediadefs.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 // Class forward declaration required for QDoc bug
@@ -289,6 +287,4 @@ namespace QMediaMetaData {
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QMEDIAMETADATA_H
