@@ -61,8 +61,6 @@
 #include <QtCore/qjsonobject.h>
 
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QFactoryLoader;
@@ -92,7 +90,5 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif  // QMEDIAPLUGINLOADER_H
