@@ -45,8 +45,6 @@
 #include <QObject>
 #include "qtmultimediadefs.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class Q_MULTIMEDIA_EXPORT QMediaResourcePolicy
@@ -68,6 +66,4 @@ T* QMediaResourcePolicy::createResourceSet()
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QMEDIARESOURCEPOLICY_H
