@@ -48,8 +48,6 @@
 
 #include <QtMultimedia/qmediacontrol.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -88,8 +86,6 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif  // QABSTRACTMEDIASERVICE_H
 
