@@ -53,8 +53,6 @@
 // We mean it.
 //
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -71,8 +69,6 @@ public:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 
 #endif
