@@ -49,8 +49,6 @@
 #include <QtMultimedia/qtmultimediadefs.h>
 #include <QtMultimedia/qmultimedia.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -180,7 +178,5 @@ Q_DECLARE_METATYPE(QAudioEncoderSettings)
 Q_DECLARE_METATYPE(QVideoEncoderSettings)
 Q_DECLARE_METATYPE(QImageEncoderSettings)
 
-QT_END_HEADER
-
 
 #endif
