@@ -48,8 +48,6 @@
 
 #include <QtCore/qmetatype.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -112,6 +110,4 @@ QT_END_NAMESPACE
 Q_DECLARE_METATYPE(QAbstractVideoBuffer::HandleType)
 Q_DECLARE_METATYPE(QAbstractVideoBuffer::MapMode)
 
-QT_END_HEADER
-
 #endif
