@@ -47,8 +47,6 @@
 #include <QtCore/qsharedpointer.h>
 #include <QtCore/qpointer.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -79,7 +77,5 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif
