@@ -65,8 +65,6 @@
 #include <qvideosurfaceformat.h>
 #include <qvideoframe.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QGLContext;
@@ -142,7 +140,5 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif
