@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the Qt Toolkit.
@@ -40,7 +40,6 @@
 ****************************************************************************/
 
 #include "qpaintervideosurface_p.h"
-#include "qpaintervideosurface_mac_p.h"
 
 #include <qmath.h>
 
@@ -51,6 +50,7 @@
 #if !defined(QT_NO_OPENGL) && !defined(QT_OPENGL_ES_1_CL) && !defined(QT_OPENGL_ES_1)
 #include <qglshaderprogram.h>
 #include <QtGui/QOpenGLContext>
+#include <QtGui/QWindow>
 #ifndef GL_CLAMP_TO_EDGE
 #define GL_CLAMP_TO_EDGE 0x812F
 #endif
@@ -357,6 +357,11 @@ QAbstractVideoSurface::Error QVideoSurfaceGLPainter::setCurrentFrame(const QVide
 
     if (m_handleType == QAbstractVideoBuffer::GLTextureHandle) {
         m_textureIds[0] = frame.handle().toInt();
+        glBindTexture(GL_TEXTURE_2D, m_textureIds[0]);
+        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
+        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
     } else if (m_frame.map(QAbstractVideoBuffer::ReadOnly)) {
         m_context->makeCurrent();
 
@@ -461,25 +466,25 @@ void QVideoSurfaceGLPainter::updateColors(int brightness, int contrast, int hue,
         switch (m_colorSpace) {
         case QVideoSurfaceFormat::YCbCr_JPEG:
             colorSpaceMatrix = QMatrix4x4(
-                        1.0,  0.000,  1.402, -0.701,
-                        1.0, -0.344, -0.714,  0.529,
-                        1.0,  1.772,  0.000, -0.886,
-                        0.0,  0.000,  0.000,  1.0000);
+                        1.0f,  0.000f,  1.402f, -0.701f,
+                        1.0f, -0.344f, -0.714f,  0.529f,
+                        1.0f,  1.772f,  0.000f, -0.886f,
+                        0.0f,  0.000f,  0.000f,  1.0000f);
             break;
         case QVideoSurfaceFormat::YCbCr_BT709:
         case QVideoSurfaceFormat::YCbCr_xvYCC709:
             colorSpaceMatrix = QMatrix4x4(
-                        1.164,  0.000,  1.793, -0.5727,
-                        1.164, -0.534, -0.213,  0.3007,
-                        1.164,  2.115,  0.000, -1.1302,
-                        0.0,    0.000,  0.000,  1.0000);
+                        1.164f,  0.000f,  1.793f, -0.5727f,
+                        1.164f, -0.534f, -0.213f,  0.3007f,
+                        1.164f,  2.115f,  0.000f, -1.1302f,
+                        0.0f,    0.000f,  0.000f,  1.0000f);
             break;
         default: //BT 601:
             colorSpaceMatrix = QMatrix4x4(
-                        1.164,  0.000,  1.596, -0.8708,
-                        1.164, -0.392, -0.813,  0.5296,
-                        1.164,  2.017,  0.000, -1.081,
-                        0.0,    0.000,  0.000,  1.0000);
+                        1.164f,  0.000f,  1.596f, -0.8708f,
+                        1.164f, -0.392f, -0.813f,  0.5296f,
+                        1.164f,  2.017f,  0.000f, -1.081f,
+                        0.0f,    0.000f,  0.000f,  1.0000f);
         }
 
         m_colorMatrix = m_colorMatrix * colorSpaceMatrix;
@@ -768,6 +773,8 @@ QAbstractVideoSurface::Error QVideoSurfaceArbFpPainter::start(const QVideoSurfac
     if (!program) {
         error = QAbstractVideoSurface::UnsupportedFormatError;
     } else {
+        while (glGetError() != GL_NO_ERROR) { } // clear previous unrelated errors
+
         glGenProgramsARB(1, &m_programId);
 
         GLenum glError = glGetError();
@@ -864,19 +871,12 @@ QAbstractVideoSurface::Error QVideoSurfaceArbFpPainter::paint(
             txRight, txTop
         };
 
-        const GLfloat vTop = m_scanLineDirection == QVideoSurfaceFormat::TopToBottom
-                ? target.top()
-                : target.bottom() + 1;
-        const GLfloat vBottom = m_scanLineDirection == QVideoSurfaceFormat::TopToBottom
-                ? target.bottom() + 1
-                : target.top();
-
         const GLfloat v_array[] =
         {
-            GLfloat(target.left())     , GLfloat(vBottom),
-            GLfloat(target.right() + 1), GLfloat(vBottom),
-            GLfloat(target.left())     , GLfloat(vTop),
-            GLfloat(target.right() + 1), GLfloat(vTop)
+            GLfloat(target.left())     , GLfloat(target.bottom() + 1),
+            GLfloat(target.right() + 1), GLfloat(target.bottom() + 1),
+            GLfloat(target.left())     , GLfloat(target.top()),
+            GLfloat(target.right() + 1), GLfloat(target.top())
         };
 
         glEnable(GL_FRAGMENT_PROGRAM_ARB);
@@ -1198,8 +1198,8 @@ QAbstractVideoSurface::Error QVideoSurfaceGlslPainter::paint(
         if (scissorTestEnabled)
             glEnable(GL_SCISSOR_TEST);
 
-        const int width = QGLContext::currentContext()->device()->width();
-        const int height = QGLContext::currentContext()->device()->height();
+        const int width = QOpenGLContext::currentContext()->surface()->size().width();
+        const int height = QOpenGLContext::currentContext()->surface()->size().height();
 
         const QTransform transform = painter->deviceTransform();
 
@@ -1231,20 +1231,12 @@ QAbstractVideoSurface::Error QVideoSurfaceGlslPainter::paint(
             }
         };
 
-        const GLfloat vTop = m_scanLineDirection == QVideoSurfaceFormat::TopToBottom
-                ? target.top()
-                : target.bottom() + 1;
-        const GLfloat vBottom = m_scanLineDirection == QVideoSurfaceFormat::TopToBottom
-                ? target.bottom() + 1
-                : target.top();
-
-
         const GLfloat vertexCoordArray[] =
         {
-            GLfloat(target.left())     , GLfloat(vBottom),
-            GLfloat(target.right() + 1), GLfloat(vBottom),
-            GLfloat(target.left())     , GLfloat(vTop),
-            GLfloat(target.right() + 1), GLfloat(vTop)
+            GLfloat(target.left())     , GLfloat(target.bottom() + 1),
+            GLfloat(target.right() + 1), GLfloat(target.bottom() + 1),
+            GLfloat(target.left())     , GLfloat(target.top()),
+            GLfloat(target.right() + 1), GLfloat(target.top())
         };
 
         const GLfloat txLeft = source.left() / m_frameSize.width();
@@ -1677,14 +1669,6 @@ void QPainterVideoSurface::createPainter()
 {
     Q_ASSERT(!m_painter);
 
-#ifdef Q_OS_MAC
-    if (m_glContext)
-        m_glContext->makeCurrent();
-
-    m_painter = new QVideoSurfaceCoreGraphicsPainter(m_glContext != 0);
-    return;
-#endif
-
 #if !defined(QT_NO_OPENGL) && !defined(QT_OPENGL_ES_1_CL) && !defined(QT_OPENGL_ES_1)
     switch (m_shaderType) {
 #ifndef QT_OPENGL_ES
