@@ -47,8 +47,6 @@
 #include <QtMultimediaWidgets/qtmultimediawidgetdefs.h>
 #include <QtMultimedia/qmediabindableinterface.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -131,7 +129,5 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 
 #endif
