@@ -240,9 +240,11 @@ static void *AVFMediaPlayerSessionObserverCurrentItemObservationContext = &AVFMe
     m_player = [AVPlayer playerWithPlayerItem:m_playerItem];
     [m_player retain];
 
+#if defined(Q_OS_OSX)
     //Set the initial volume on new player object
     if (self.session)
         m_player.volume = m_session->volume() / 100.0f;
+#endif
 
     //Create a new player layer if we don't have one already
     if (!m_playerLayer)
@@ -283,7 +285,7 @@ static void *AVFMediaPlayerSessionObserverCurrentItemObservationContext = &AVFMe
 -(void) assetFailedToPrepareForPlayback:(NSError *)error
 {
     Q_UNUSED(error)
-    //TODO: Let the session know that the assest failed to prepare for playback
+    QMetaObject::invokeMethod(m_session, "processMediaLoadError", Qt::AutoConnection);
 #ifdef QT_DEBUG_AVF
     qDebug() << Q_FUNC_INFO;
     qDebug() << [[error localizedDescription] UTF8String];
@@ -357,7 +359,7 @@ static void *AVFMediaPlayerSessionObserverCurrentItemObservationContext = &AVFMe
     else if (context == AVFMediaPlayerSessionObserverCurrentItemObservationContext)
     {
         AVPlayerItem *newPlayerItem = [change objectForKey:NSKeyValueChangeNewKey];
-        if (m_playerItem != newPlayerItem);
+        if (m_playerItem != newPlayerItem)
         {
             m_playerItem = newPlayerItem;
 
@@ -447,7 +449,7 @@ void AVFMediaPlayerSession::setVideoOutput(AVFVideoOutput *output)
     if (m_videoOutput == output)
         return;
 
-    //Set the current ouput layer to null to stop rendering
+    //Set the current output layer to null to stop rendering
     if (m_videoOutput) {
         m_videoOutput->setLayer(0);
     }
@@ -735,10 +737,12 @@ void AVFMediaPlayerSession::setVolume(int volume)
 
     m_volume = volume;
 
+#if defined(Q_OS_OSX)
     AVPlayer *player = [(AVFMediaPlayerSessionObserver*)m_observer player];
     if (player) {
         [[(AVFMediaPlayerSessionObserver*)m_observer player] setVolume:m_volume / 100.0f];
     }
+#endif
 
     Q_EMIT volumeChanged(m_volume);
 }
@@ -752,9 +756,9 @@ void AVFMediaPlayerSession::setMuted(bool muted)
         return;
 
     m_muted = muted;
-
+#if defined(Q_OS_OSX)
     [[(AVFMediaPlayerSessionObserver*)m_observer player] setMuted:m_muted];
-
+#endif
     Q_EMIT mutedChanged(muted);
 }
 
@@ -799,13 +803,6 @@ void AVFMediaPlayerSession::processLoadStateChange()
             [[(AVFMediaPlayerSessionObserver*)m_observer player] setRate:m_rate];
             [[(AVFMediaPlayerSessionObserver*)m_observer player] play];
         }
-
-    } else {
-        Q_EMIT error(QMediaPlayer::FormatError, tr("Failed to load media"));
-        Q_EMIT mediaStatusChanged(m_mediaStatus = QMediaPlayer::InvalidMedia);
-        Q_EMIT stateChanged(m_state = QMediaPlayer::StoppedState);
-
-        return;
     }
 
     if (newStatus != m_mediaStatus)
@@ -817,6 +814,13 @@ void AVFMediaPlayerSession::processPositionChange()
     Q_EMIT positionChanged(position());
 }
 
+void AVFMediaPlayerSession::processMediaLoadError()
+{
+    Q_EMIT error(QMediaPlayer::FormatError, tr("Failed to load media"));
+    Q_EMIT mediaStatusChanged(m_mediaStatus = QMediaPlayer::InvalidMedia);
+    Q_EMIT stateChanged(m_state = QMediaPlayer::StoppedState);
+}
+
 void AVFMediaPlayerSession::processCurrentItemChanged()
 {
 #ifdef QT_DEBUG_AVF
