@@ -46,17 +46,13 @@
 
 #include <qmediaservice.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class DSCameraControl;
 class DSCameraSession;
 class DSVideoOutputControl;
 class DSVideoDeviceControl;
-class DSVideoRendererControl;
 class DSImageCaptureControl;
-class DSVideoWidgetControl;
 
 
 class DSCameraService : public QMediaService
@@ -75,16 +71,14 @@ private:
     DSCameraSession        *m_session;
     DSVideoOutputControl   *m_videoOutput;
 #if defined(HAVE_WIDGETS)
-    DSVideoWidgetControl   *m_viewFinderWidget;
+    QMediaControl          *m_viewFinderWidget;
 #endif
     DSVideoDeviceControl   *m_videoDevice;
-    DSVideoRendererControl *m_videoRenderer;
+    QMediaControl          *m_videoRenderer;
     DSImageCaptureControl  *m_imageCapture;
     QByteArray m_device;
 };
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
