@@ -174,6 +174,7 @@ HRESULT DirectShowIOSource::GetClassID(CLSID *pClassID)
 // IMediaFilter
 HRESULT DirectShowIOSource::Run(REFERENCE_TIME tStart)
 {
+    Q_UNUSED(tStart)
     QMutexLocker locker(&m_mutex);
 
     m_state = State_Running;
@@ -627,7 +628,7 @@ bool DirectShowRcSource::open(const QUrl &url)
     qDebug("qrc file %s", qPrintable(m_file.fileName()));
 
     if (m_file.open(QIODevice::ReadOnly)) {
-        qDebug("Size %d", m_file.size());
+        qDebug("Size %d", int(m_file.size()));
         qDebug("Sequential %d", int(m_file.isSequential()));
 
         setDevice(&m_file);
