@@ -115,10 +115,11 @@ void CameraBinControl::setCaptureMode(QCamera::CaptureModes mode)
                         captureMode() == QCamera::CaptureStillImage ?
                             CamerabinResourcePolicy::ImageCaptureResources :
                             CamerabinResourcePolicy::VideoCaptureResources);
-
+#if (GST_VERSION_MAJOR == 0) && ((GST_VERSION_MINOR < 10) || (GST_VERSION_MICRO < 23))
             //due to bug in v4l2src, it's necessary to reload camera on video caps changes
             //https://bugzilla.gnome.org/show_bug.cgi?id=649832
             reloadLater();
+#endif
         }
         emit captureModeChanged(mode);
     }
@@ -149,7 +150,7 @@ void CameraBinControl::setState(QCamera::State state)
             return;
         }
 
-        CamerabinResourcePolicy::ResourceSet resourceSet;
+        CamerabinResourcePolicy::ResourceSet resourceSet = CamerabinResourcePolicy::NoResources;
         switch (state) {
         case QCamera::UnloadedState:
             resourceSet = CamerabinResourcePolicy::NoResources;
@@ -201,7 +202,9 @@ void CameraBinControl::updateStatus()
     case QCamera::LoadedState:
         switch (sessionState) {
         case QCamera::UnloadedState:
-            m_status = QCamera::LoadingStatus;
+            m_status = m_resourcePolicy->isResourcesGranted()
+                    ? QCamera::LoadingStatus
+                    : QCamera::UnavailableStatus;
             break;
         case QCamera::LoadedState:
             m_status = QCamera::LoadedStatus;
@@ -214,7 +217,9 @@ void CameraBinControl::updateStatus()
     case QCamera::ActiveState:
         switch (sessionState) {
         case QCamera::UnloadedState:
-            m_status = QCamera::LoadingStatus;
+            m_status = m_resourcePolicy->isResourcesGranted()
+                    ? QCamera::LoadingStatus
+                    : QCamera::UnavailableStatus;
             break;
         case QCamera::LoadedState:
             m_status = QCamera::StartingStatus;
