@@ -48,8 +48,6 @@
 #include <QtCore/qmetaobject.h>
 
 //#define CAMERABIN_DEBUG 1
-#define ZOOM_PROPERTY "zoom"
-#define MAX_ZOOM_PROPERTY "max-zoom"
 
 QT_BEGIN_NAMESPACE
 
@@ -60,6 +58,8 @@ CameraBinFocus::CameraBinFocus(CameraBinSession *session)
      m_focusStatus(QCamera::Unlocked),
      m_focusZoneStatus(QCameraFocusZone::Selected)
 {
+    gst_photography_set_focus_mode(m_session->photography(), GST_PHOTOGRAPHY_FOCUS_MODE_AUTO);
+
     connect(m_session, SIGNAL(stateChanged(QCamera::State)),
             this, SLOT(_q_handleCameraStateChange(QCamera::State)));
 }
@@ -68,53 +68,56 @@ CameraBinFocus::~CameraBinFocus()
 {
 }
 
-QCameraFocus::FocusMode CameraBinFocus::focusMode() const
+QCameraFocus::FocusModes CameraBinFocus::focusMode() const
 {
     return m_focusMode;
 }
 
-void CameraBinFocus::setFocusMode(QCameraFocus::FocusMode mode)
+void CameraBinFocus::setFocusMode(QCameraFocus::FocusModes mode)
 {
-    if (isFocusModeSupported(mode)) {
-        m_focusMode = mode;
+    GstFocusMode photographyMode;
+
+    switch (mode) {
+    case QCameraFocus::AutoFocus:
+        photographyMode = GST_PHOTOGRAPHY_FOCUS_MODE_AUTO;
+        break;
+    case QCameraFocus::HyperfocalFocus:
+        photographyMode = GST_PHOTOGRAPHY_FOCUS_MODE_HYPERFOCAL;
+        break;
+    case QCameraFocus::InfinityFocus:
+        photographyMode = GST_PHOTOGRAPHY_FOCUS_MODE_INFINITY;
+        break;
+    case QCameraFocus::ContinuousFocus:
+        photographyMode = GST_PHOTOGRAPHY_FOCUS_MODE_CONTINUOUS_NORMAL;
+        break;
+    case QCameraFocus::MacroFocus:
+        photographyMode = GST_PHOTOGRAPHY_FOCUS_MODE_MACRO;
+        break;
+    default:
+        if (mode & QCameraFocus::AutoFocus) {
+            photographyMode = GST_PHOTOGRAPHY_FOCUS_MODE_AUTO;
+            break;
+        } else {
+            return;
+        }
     }
+
+    if (gst_photography_set_focus_mode(m_session->photography(), photographyMode))
+        m_focusMode = mode;
 }
 
-bool CameraBinFocus::isFocusModeSupported(QCameraFocus::FocusMode mode) const
+bool CameraBinFocus::isFocusModeSupported(QCameraFocus::FocusModes mode) const
 {
-    return mode & QCameraFocus::AutoFocus;
-}
-
-qreal CameraBinFocus::maximumOpticalZoom() const
-{
-    return 1.0;
-}
-
-qreal CameraBinFocus::maximumDigitalZoom() const
-{
-    gfloat zoomFactor = 1.0;
-    g_object_get(GST_BIN(m_session->cameraBin()), MAX_ZOOM_PROPERTY, &zoomFactor, NULL);
-    return zoomFactor;
-}
-
-qreal CameraBinFocus::opticalZoom() const
-{
-    return 1.0;
-}
-
-qreal CameraBinFocus::digitalZoom() const
-{
-    gfloat zoomFactor = 1.0;
-    g_object_get(GST_BIN(m_session->cameraBin()), ZOOM_PROPERTY, &zoomFactor, NULL);
-    return zoomFactor;
-}
-
-void CameraBinFocus::zoomTo(qreal optical, qreal digital)
-{
-    Q_UNUSED(optical);
-    digital = qBound(qreal(1.0), digital, maximumDigitalZoom());
-    g_object_set(GST_BIN(m_session->cameraBin()), ZOOM_PROPERTY, digital, NULL);
-    emit digitalZoomChanged(digital);
+    switch (mode) {
+    case QCameraFocus::AutoFocus:
+    case QCameraFocus::HyperfocalFocus:
+    case QCameraFocus::InfinityFocus:
+    case QCameraFocus::ContinuousFocus:
+    case QCameraFocus::MacroFocus:
+        return true;
+    default:
+        return mode & QCameraFocus::AutoFocus;
+    }
 }
 
 QCameraFocus::FocusPointMode CameraBinFocus::focusPointMode() const
