@@ -42,9 +42,7 @@
 #include "camerabinimageprocessing.h"
 #include "camerabinsession.h"
 
-#ifdef HAVE_GST_PHOTOGRAPHY
-#include <gst/interfaces/photography.h>
-#endif
+#include <gst/interfaces/colorbalance.h>
 
 QT_BEGIN_NAMESPACE
 
@@ -190,7 +188,9 @@ bool CameraBinImageProcessing::isParameterValueSupported(QCameraImageProcessingC
 QVariant CameraBinImageProcessing::parameter(
         QCameraImageProcessingControl::ProcessingParameter parameter) const
 {
-    if (m_values.contains(parameter))
+    if (parameter == QCameraImageProcessingControl::WhiteBalancePreset)
+        return QVariant::fromValue<QCameraImageProcessing::WhiteBalanceMode>(whiteBalanceMode());
+    else if (m_values.contains(parameter))
         return m_values.value(parameter);
     else
         return QVariant();
