@@ -54,23 +54,24 @@
 #include "camerabinflash.h"
 #include "camerabinfocus.h"
 #include "camerabinlocks.h"
+#include "camerabinzoom.h"
 #endif
 
 #include "camerabinimagecapture.h"
 #include "camerabinimageprocessing.h"
 #include "camerabincapturebufferformat.h"
 #include "camerabincapturedestination.h"
+#include "camerabinviewfindersettings.h"
 #include <private/qgstreamerbushelper_p.h>
 
 #include <private/qgstreameraudioinputselector_p.h>
 #include <private/qgstreamervideoinputdevicecontrol_p.h>
 
+
 #if defined(HAVE_WIDGETS)
-#include <private/qgstreamervideooverlay_p.h>
-#include <private/qgstreamervideowindow_p.h>
 #include <private/qgstreamervideowidget_p.h>
 #endif
-
+#include <private/qgstreamervideowindow_p.h>
 #include <private/qgstreamervideorenderer_p.h>
 
 #if defined(Q_WS_MAEMO_6) && defined(__arm__)
@@ -92,7 +93,6 @@ CameraBinService::CameraBinService(const QString &service, QObject *parent):
     QMediaService(parent)
 {
     m_captureSession = 0;
-    m_cameraControl = 0;
     m_metaDataControl = 0;
 
     m_audioInputSelector = 0;
@@ -100,16 +100,16 @@ CameraBinService::CameraBinService(const QString &service, QObject *parent):
 
     m_videoOutput = 0;
     m_videoRenderer = 0;
-#if defined(HAVE_XVIDEO) && defined(HAVE_WIDGETS)
     m_videoWindow = 0;
+#if defined(HAVE_WIDGETS)
     m_videoWidgetControl = 0;
 #endif
     m_imageCaptureControl = 0;
 
     if (service == Q_MEDIASERVICE_CAMERA) {
         m_captureSession = new CameraBinSession(this);
-        m_cameraControl = new CameraBinControl(m_captureSession);
-        m_videoInputDevice = new QGstreamerVideoInputDeviceControl(m_captureSession);
+        m_videoInputDevice = new QGstreamerVideoInputDeviceControl(
+                    m_captureSession->buildCameraSource(), m_captureSession);
         m_imageCaptureControl = new CameraBinImageCapture(m_captureSession);
 
         connect(m_videoInputDevice, SIGNAL(selectedDeviceChanged(QString)),
@@ -124,12 +124,13 @@ CameraBinService::CameraBinService(const QString &service, QObject *parent):
         m_videoRenderer = new QGstreamerVideoRenderer(this);
 #endif
 
-#if defined(HAVE_XVIDEO) && defined(HAVE_WIDGETS)
 #ifdef Q_WS_MAEMO_6
         m_videoWindow = new QGstreamerVideoWindow(this, "omapxvsink");
 #else
-        m_videoWindow = new QGstreamerVideoOverlay(this);
+        m_videoWindow = new QGstreamerVideoWindow(this);
 #endif
+
+#if defined(HAVE_WIDGETS)
         m_videoWidgetControl = new QGstreamerVideoWidgetControl(this);
 #endif
 
@@ -168,11 +169,11 @@ QMediaControl *CameraBinService::requestControl(const char *name)
     if (!m_videoOutput) {
         if (qstrcmp(name, QVideoRendererControl_iid) == 0) {
             m_videoOutput = m_videoRenderer;
-        }
-#if defined(HAVE_XVIDEO) && defined(HAVE_WIDGETS)
-        else if (qstrcmp(name, QVideoWindowControl_iid) == 0) {
+        } else if (qstrcmp(name, QVideoWindowControl_iid) == 0) {
             m_videoOutput = m_videoWindow;
-        } else if (qstrcmp(name, QVideoWidgetControl_iid) == 0) {
+        }
+#if defined(HAVE_WIDGETS)
+        else if (qstrcmp(name, QVideoWidgetControl_iid) == 0) {
             m_videoOutput = m_videoWidgetControl;
         }
 #endif
@@ -206,7 +207,7 @@ QMediaControl *CameraBinService::requestControl(const char *name)
         return m_captureSession->mediaContainerControl();
 
     if (qstrcmp(name,QCameraControl_iid) == 0)
-        return m_cameraControl;
+        return m_captureSession->cameraControl();
 
     if (qstrcmp(name,QMetaDataWriterControl_iid) == 0)
         return m_metaDataControl;
@@ -226,6 +227,9 @@ QMediaControl *CameraBinService::requestControl(const char *name)
 
     if (qstrcmp(name, QCameraLocksControl_iid) == 0)
         return m_captureSession->cameraLocksControl();
+
+    if (qstrcmp(name, QCameraZoomControl_iid) == 0)
+        return m_captureSession->cameraZoomControl();
 #endif
 
     if (qstrcmp(name, QCameraImageProcessingControl_iid) == 0)
@@ -237,6 +241,9 @@ QMediaControl *CameraBinService::requestControl(const char *name)
     if (qstrcmp(name, QCameraCaptureBufferFormatControl_iid) == 0)
         return m_captureSession->captureBufferFormatControl();
 
+    if (qstrcmp(name, QCameraViewfinderSettingsControl_iid) == 0)
+        return m_captureSession->viewfinderSettingsControl();
+
     return 0;
 }
 
