@@ -39,6 +39,7 @@
 **
 ****************************************************************************/
 #include "camerabinsession.h"
+#include "camerabincontrol.h"
 #include "camerabinrecorder.h"
 #include "camerabincontainer.h"
 #include "camerabinaudioencoder.h"
@@ -50,9 +51,11 @@
 #include "camerabinflash.h"
 #include "camerabinfocus.h"
 #include "camerabinlocks.h"
+#include "camerabinzoom.h"
 #endif
 
 #include "camerabinimageprocessing.h"
+#include "camerabinviewfindersettings.h"
 
 #include "camerabincapturedestination.h"
 #include "camerabincapturebufferformat.h"
@@ -73,6 +76,7 @@
 #include <QtGui/qdesktopservices.h>
 
 #include <QtGui/qimage.h>
+#include <QtCore/qdatetime.h>
 
 //#define CAMERABIN_DEBUG 1
 //#define CAMERABIN_DEBUG_DUMP_BIN 1
@@ -89,6 +93,8 @@
 #define AUDIO_SOURCE_PROPERTY "audio-source"
 #define SUPPORTED_IMAGE_CAPTURE_CAPS_PROPERTY "image-capture-supported-caps"
 #define SUPPORTED_VIDEO_CAPTURE_CAPS_PROPERTY "video-capture-supported-caps"
+#define SUPPORTED_VIEWFINDER_CAPS_PROPERTY "viewfinder-supported-caps"
+#define AUDIO_CAPTURE_CAPS_PROPERTY "audio-capture-caps"
 #define IMAGE_CAPTURE_CAPS_PROPERTY "image-capture-caps"
 #define VIDEO_CAPTURE_CAPS_PROPERTY "video-capture-caps"
 #define VIEWFINDER_CAPS_PROPERTY "viewfinder-caps"
@@ -108,10 +114,6 @@
 #define PREVIEW_CAPS_4_3 \
     "video/x-raw-rgb, width = (int) 640, height = (int) 480"
 
-#define VIEWFINDER_RESOLUTION_4x3 QSize(640, 480)
-#define VIEWFINDER_RESOLUTION_3x2 QSize(720, 480)
-#define VIEWFINDER_RESOLUTION_16x9 QSize(800, 450)
-
 //using GST_STATE_READY for QCamera::LoadedState
 //may not work reliably at least with some webcams.
 
@@ -151,6 +153,7 @@ CameraBinSession::CameraBinSession(QObject *parent)
     m_busHelper = new QGstreamerBusHelper(m_bus, this);
     m_busHelper->installMessageFilter(this);
 
+    m_cameraControl = new CameraBinControl(this);
     m_audioEncodeControl = new CameraBinAudioEncoder(this);
     m_videoEncodeControl = new CameraBinVideoEncoder(this);
     m_imageEncodeControl = new CameraBinImageEncoder(this);
@@ -162,10 +165,16 @@ CameraBinSession::CameraBinSession(QObject *parent)
     m_cameraFlashControl = new CameraBinFlash(this);
     m_cameraFocusControl = new CameraBinFocus(this);
     m_cameraLocksControl = new CameraBinLocks(this);
+    m_cameraZoomControl = new CameraBinZoom(this);
 #endif
     m_imageProcessingControl = new CameraBinImageProcessing(this);
     m_captureDestinationControl = new CameraBinCaptureDestination(this);
     m_captureBufferFormatControl = new CameraBinCaptureBufferFormat(this);
+    m_viewfinderSettingsControl = new CameraBinViewfinderSettings(this);
+
+    QByteArray envFlags = qgetenv("QT_GSTREAMER_CAMERABIN_FLAGS");
+    if (!envFlags.isEmpty())
+        g_object_set(G_OBJECT(m_camerabin), "flags", envFlags.toInt(), NULL);
 
     //post image preview in RGB format
     g_object_set(G_OBJECT(m_camerabin), POST_PREVIEWS_PROPERTY, TRUE, NULL);
@@ -195,19 +204,10 @@ GstPhotography *CameraBinSession::photography()
         return GST_PHOTOGRAPHY(m_camerabin);
     }
 
-    if (!m_videoSrc) {
-        m_videoSrc = buildCameraSource();
+    GstElement * const source = buildCameraSource();
 
-        if (m_videoSrc)
-            g_object_set(m_camerabin, CAMERA_SOURCE_PROPERTY, m_videoSrc, NULL);
-        else
-            g_object_get(m_camerabin, CAMERA_SOURCE_PROPERTY, &m_videoSrc, NULL);
-
-        m_videoInputHasChanged = false;
-    }
-
-    if (m_videoSrc && GST_IS_PHOTOGRAPHY(m_videoSrc))
-        return GST_PHOTOGRAPHY(m_videoSrc);
+    if (source && GST_IS_PHOTOGRAPHY(source))
+        return GST_PHOTOGRAPHY(source);
 
     return 0;
 }
@@ -223,17 +223,8 @@ CameraBinSession::CameraRole CameraBinSession::cameraRole() const
 */
 bool CameraBinSession::setupCameraBin()
 {
-    if (m_videoInputHasChanged) {
-        m_videoSrc = buildCameraSource();
-
-        if (m_videoSrc)
-            g_object_set(m_camerabin, CAMERA_SOURCE_PROPERTY, m_videoSrc, NULL);
-        else
-            g_object_get(m_camerabin, CAMERA_SOURCE_PROPERTY, &m_videoSrc, NULL);
-
-        m_videoInputHasChanged = false;
-    }
-
+    if (!buildCameraSource())
+        return false;
 
     if (m_viewfinderHasChanged) {
         if (m_viewfinderElement)
@@ -256,8 +247,7 @@ bool CameraBinSession::setupCameraBin()
     return true;
 }
 
-static GstCaps *resolutionToCaps(const QSize &resolution,
-                                  const QPair<int, int> &rate = qMakePair<int,int>(0,0))
+static GstCaps *resolutionToCaps(const QSize &resolution, const QPair<int, int> &rate = qMakePair<int,int>(0,0))
 {
     if (resolution.isEmpty())
         return gst_caps_new_any();
@@ -273,7 +263,23 @@ static GstCaps *resolutionToCaps(const QSize &resolution,
                                                    "width", G_TYPE_INT, resolution.width(),
                                                    "height", G_TYPE_INT, resolution.height(),
                                                    "framerate", GST_TYPE_FRACTION, rate.first, rate.second,
-                                                   NULL), NULL);
+                                                   NULL),
+                                 gst_structure_new("video/x-raw-data",
+                                                   "width", G_TYPE_INT, resolution.width(),
+                                                   "height", G_TYPE_INT, resolution.height(),
+                                                   "framerate", GST_TYPE_FRACTION, rate.first, rate.second,
+                                                   NULL),
+                                gst_structure_new("video/x-android-buffer",
+                                                   "width", G_TYPE_INT, resolution.width(),
+                                                                                    "height", G_TYPE_INT, resolution.height(),
+                                                                                    "framerate", GST_TYPE_FRACTION, rate.first, rate.second,
+                                                                                    NULL),
+                                 gst_structure_new("image/jpeg",
+                                                   "width", G_TYPE_INT, resolution.width(),
+                                                   "height", G_TYPE_INT, resolution.height(),
+                                                   "framerate", GST_TYPE_FRACTION, rate.first, rate.second,
+                                                   NULL),
+                                 NULL);
     } else {
         caps = gst_caps_new_full (gst_structure_new ("video/x-raw-yuv",
                                                      "width", G_TYPE_INT, resolution.width(),
@@ -281,115 +287,134 @@ static GstCaps *resolutionToCaps(const QSize &resolution,
                                                      NULL),
                                   gst_structure_new ("video/x-raw-rgb",
                                                      "width", G_TYPE_INT, resolution.width(),
-                                                     "height", G_TYPE_INT, resolution.height(), NULL), NULL);
+                                                     "height", G_TYPE_INT, resolution.height(),
+                                                     NULL),
+                                  gst_structure_new("video/x-raw-data",
+                                                    "width", G_TYPE_INT, resolution.width(),
+                                                    "height", G_TYPE_INT, resolution.height(),
+                                                    NULL),
+                                  gst_structure_new ("video/x-android-buffer",
+                                                     "width", G_TYPE_INT, resolution.width(),
+                                                     "height", G_TYPE_INT, resolution.height(),
+                                                     NULL),
+                                  gst_structure_new ("image/jpeg",
+                                                     "width", G_TYPE_INT, resolution.width(),
+                                                     "height", G_TYPE_INT, resolution.height(),
+                                                     NULL),
+                                  NULL);
     }
+
     return caps;
 }
 
 void CameraBinSession::setupCaptureResolution()
 {
-    if (m_captureMode == QCamera::CaptureStillImage) {
-        QSize resolution = m_imageEncodeControl->imageSettings().resolution();
-
-        //by default select the maximum supported resolution
-        if (resolution.isEmpty()) {
-            bool continuous = false;
-            QList<QSize> resolutions = supportedResolutions(qMakePair<int,int>(0,0),
-                                                            &continuous,
-                                                            QCamera::CaptureStillImage);
-            if (!resolutions.isEmpty())
-                resolution = resolutions.last();
-        }
-
-        QSize viewfinderResolution = VIEWFINDER_RESOLUTION_4x3;
-
-        if (!resolution.isEmpty()) {
-            GstCaps *caps = resolutionToCaps(resolution);
+    QSize resolution = m_imageEncodeControl->imageSettings().resolution();
+    if (!resolution.isEmpty()) {
+        GstCaps *caps = resolutionToCaps(resolution);
 #if CAMERABIN_DEBUG
-            qDebug() << Q_FUNC_INFO << "set image resolution" << resolution << gst_caps_to_string(caps);
+        qDebug() << Q_FUNC_INFO << "set image resolution" << resolution << gst_caps_to_string(caps);
 #endif
-            g_object_set(m_camerabin, IMAGE_CAPTURE_CAPS_PROPERTY, caps, NULL);
-            gst_caps_unref(caps);
-
-            if (!resolution.isEmpty()) {
-                qreal aspectRatio = qreal(resolution.width()) / resolution.height();
-                if (aspectRatio < 1.4)
-                    viewfinderResolution = VIEWFINDER_RESOLUTION_4x3;
-                else if (aspectRatio > 1.7)
-                    viewfinderResolution = VIEWFINDER_RESOLUTION_16x9;
-                else
-                    viewfinderResolution = VIEWFINDER_RESOLUTION_3x2;
-            }
-        } else {
-            g_object_set(m_camerabin, IMAGE_CAPTURE_CAPS_PROPERTY, GST_CAPS_ANY, NULL);
-        }
-
-        //on low res cameras the viewfinder resolution should not be bigger
-        //then capture resolution
-        if (viewfinderResolution.width() > resolution.width() && !resolution.isEmpty())
-            viewfinderResolution = resolution;
-
-        GstCaps *viewfinderCaps = resolutionToCaps(viewfinderResolution);
-#if CAMERABIN_DEBUG
-        qDebug() << "Set viewfinder resolution" << viewfinderResolution <<gst_caps_to_string(viewfinderCaps);
-#endif
-        g_object_set(m_camerabin, VIEWFINDER_CAPS_PROPERTY, viewfinderCaps, NULL);
-        gst_caps_unref(viewfinderCaps);
+        g_object_set(m_camerabin, IMAGE_CAPTURE_CAPS_PROPERTY, caps, NULL);
+        gst_caps_unref(caps);
+    } else {
+        g_object_set(m_camerabin, IMAGE_CAPTURE_CAPS_PROPERTY, NULL, NULL);
     }
 
-    if (m_captureMode == QCamera::CaptureVideo) {
-        QSize resolution = m_videoEncodeControl->actualVideoSettings().resolution();
-        //qreal framerate = m_videoEncodeControl->videoSettings().frameRate();
-
-        if (resolution.isEmpty()) {
-            //select the hightest supported resolution
-            bool continuous = false;
-            QList<QSize> resolutions = supportedResolutions(qMakePair<int,int>(0,0),
-                                                            &continuous,
-                                                            QCamera::CaptureVideo);
-            if (!resolutions.isEmpty())
-                resolution = resolutions.last();
-        }
-
+    resolution = m_videoEncodeControl->actualVideoSettings().resolution();
+    //qreal framerate = m_videoEncodeControl->videoSettings().frameRate();
+    if (!resolution.isEmpty()) {
         GstCaps *caps = resolutionToCaps(resolution /*, framerate*/); //convert to rational
 #if CAMERABIN_DEBUG
         qDebug() << Q_FUNC_INFO << "set video resolution" << resolution << gst_caps_to_string(caps);
 #endif
-
-        //Use the same resolution for viewfinder and video capture
         g_object_set(m_camerabin, VIDEO_CAPTURE_CAPS_PROPERTY, caps, NULL);
+        gst_caps_unref(caps);
+    } else {
+        g_object_set(m_camerabin, VIDEO_CAPTURE_CAPS_PROPERTY, NULL, NULL);
+    }
+
+    resolution = m_viewfinderSettingsControl->resolution();
+    if (!resolution.isEmpty()) {
+        GstCaps *caps = resolutionToCaps(resolution);
+#if CAMERABIN_DEBUG
+        qDebug() << Q_FUNC_INFO << "set viewfinder resolution" << resolution << gst_caps_to_string(caps);
+#endif
         g_object_set(m_camerabin, VIEWFINDER_CAPS_PROPERTY, caps, NULL);
         gst_caps_unref(caps);
+    } else {
+        g_object_set(m_camerabin, VIEWFINDER_CAPS_PROPERTY, NULL, NULL);
     }
 }
 
+void CameraBinSession::setAudioCaptureCaps()
+{
+    QAudioEncoderSettings settings = m_audioEncodeControl->audioSettings();
+    const int sampleRate = settings.sampleRate();
+    const int channelCount = settings.channelCount();
+
+    if (sampleRate == -1 && channelCount == -1)
+        return;
+
+    GstStructure *structure = gst_structure_new(
+                "audio/x-raw-int",
+                "endianness", G_TYPE_INT, 1234,
+                "signed", G_TYPE_BOOLEAN, TRUE,
+                "width", G_TYPE_INT, 16,
+                "depth", G_TYPE_INT, 16,
+                NULL);
+    if (sampleRate != -1)
+        gst_structure_set(structure, "rate", G_TYPE_INT, sampleRate, NULL);
+    if (channelCount != -1)
+        gst_structure_set(structure, "channels", G_TYPE_INT, channelCount, NULL);
+
+    GstCaps *caps = gst_caps_new_full(structure, NULL);
+    g_object_set(G_OBJECT(m_camerabin), AUDIO_CAPTURE_CAPS_PROPERTY, caps, NULL);
+    gst_caps_unref(caps);
+}
+
 GstElement *CameraBinSession::buildCameraSource()
 {
 #if CAMERABIN_DEBUG
     qDebug() << Q_FUNC_INFO;
 #endif
+    if (!m_videoInputHasChanged)
+        return m_videoSrc;
+    m_videoInputHasChanged = false;
+
     GstElement *videoSrc = 0;
+    g_object_get(G_OBJECT(m_camerabin), CAMERA_SOURCE_PROPERTY, &videoSrc, NULL);
 
-    QList<QByteArray> candidates;
-    candidates << "subdevsrc" << "wrappercamerabinsrc";
-    QByteArray sourceElementName;
-
-    foreach (sourceElementName, candidates) {
-        videoSrc = gst_element_factory_make(sourceElementName.constData(), "camera_source");
-        if (videoSrc)
-            break;
+    // If the QT_GSTREAMER_CAMERABIN_SRC environment variable has been set use the source
+    // it recommends.
+    const QByteArray envCandidate = qgetenv("QT_GSTREAMER_CAMERABIN_SRC");
+    if (!m_videoSrc && !envCandidate.isEmpty()) {
+        m_videoSrc = gst_element_factory_make(envCandidate.constData(), "camera_source");
     }
 
-    if (videoSrc && !m_inputDevice.isEmpty()) {
+    // If gstreamer has set a default source use it.
+    if (!m_videoSrc)
+        m_videoSrc = videoSrc;
+
+    // If there's no better guidance try the names of some known camera source elements.
+    if (!m_videoSrc) {
+        const QList<QByteArray> candidates = QList<QByteArray>()
+                << "subdevsrc"
+                << "wrappercamerabinsrc";
+
+        foreach (const QByteArray &sourceElementName, candidates) {
+            m_videoSrc = gst_element_factory_make(sourceElementName.constData(), "camera_source");
+            if (m_videoSrc)
+                break;
+        }
+    }
+
+    if (m_videoSrc && !m_inputDevice.isEmpty()) {
 #if CAMERABIN_DEBUG
         qDebug() << "set camera device" << m_inputDevice;
 #endif
-        if (sourceElementName == "subdevsrc") {
-            if (m_inputDevice == QLatin1String("secondary"))
-                g_object_set(G_OBJECT(videoSrc), "camera-device", 1, NULL);
-            else
-                g_object_set(G_OBJECT(videoSrc), "camera-device", 0, NULL);
-        } else if (sourceElementName == "wrappercamerabinsrc") {
+
+        if (g_object_class_find_property(G_OBJECT_GET_CLASS(m_videoSrc), "video-source")) {
             GstElement *src = 0;
 
             if (m_videoInputFactory)
@@ -399,12 +424,21 @@ GstElement *CameraBinSession::buildCameraSource()
 
             if (src) {
                 g_object_set(G_OBJECT(src), "device", m_inputDevice.toUtf8().constData(), NULL);
-                g_object_set(G_OBJECT(videoSrc), "video-source", src, NULL);
+                g_object_set(G_OBJECT(m_videoSrc), "video-source", src, NULL);
+            }
+        } else if (g_object_class_find_property(G_OBJECT_GET_CLASS(m_videoSrc), "camera-device")) {
+            if (m_inputDevice == QLatin1String("secondary")) {
+                g_object_set(G_OBJECT(m_videoSrc), "camera-device", 1, NULL);
+            } else {
+                g_object_set(G_OBJECT(m_videoSrc), "camera-device", 0, NULL);
             }
         }
     }
 
-    return videoSrc;
+    if (m_videoSrc != videoSrc)
+        g_object_set(G_OBJECT(m_camerabin), CAMERA_SOURCE_PROPERTY, m_videoSrc, NULL);
+
+    return m_videoSrc;
 }
 
 void CameraBinSession::captureImage(int requestId, const QString &fileName)
@@ -438,6 +472,8 @@ void CameraBinSession::setCaptureMode(QCamera::CaptureModes mode)
         g_object_set(m_camerabin, MODE_PROPERTY, CAMERABIN_VIDEO_MODE, NULL);
         break;
     }
+
+    m_recorderControl->updateStatus();
 }
 
 QUrl CameraBinSession::outputLocation() const
@@ -624,9 +660,7 @@ void CameraBinSession::setState(QCamera::State newState)
                 m_viewfinderInterface->stopRenderer();
 
             gst_element_set_state(m_camerabin, GST_STATE_NULL);
-            m_videoSrc = buildCameraSource();
-            g_object_set(m_camerabin, CAMERA_SOURCE_PROPERTY, m_videoSrc, NULL);
-            m_videoInputHasChanged = false;
+            buildCameraSource();
         }
 #ifdef USE_READY_STATE_ON_LOADED
         gst_element_set_state(m_camerabin, GST_STATE_READY);
@@ -644,14 +678,14 @@ void CameraBinSession::setState(QCamera::State newState)
             GstState pending = GST_STATE_NULL;
             gst_element_get_state(m_camerabin, &binState, &pending, 0);
 
-            if (captureMode() == QCamera::CaptureVideo) {
-                m_recorderControl->applySettings();
+            m_recorderControl->applySettings();
 
-                g_object_set (G_OBJECT(m_camerabin),
-                              "video-profile",
-                              m_recorderControl->videoProfile(),
-                              NULL);
-            }
+            g_object_set (G_OBJECT(m_camerabin),
+                          "video-profile",
+                          m_recorderControl->videoProfile(),
+                          NULL);
+
+            setAudioCaptureCaps();
 
             setupCaptureResolution();
 
@@ -670,7 +704,7 @@ void CameraBinSession::updateBusyStatus(GObject *o, GParamSpec *p, gpointer d)
     Q_UNUSED(p);
     CameraBinSession *session = reinterpret_cast<CameraBinSession *>(d);
 
-    bool idle = false;
+    gboolean idle = false;
     g_object_get(o, "idle", &idle, NULL);
     bool busy = !idle;
 
@@ -731,7 +765,7 @@ void CameraBinSession::setMetaData(const QMap<QByteArray, QVariant> &data)
                 switch(tagValue.type()) {
                     case QVariant::String:
                         gst_tag_setter_add_tags(GST_TAG_SETTER(element),
-                            GST_TAG_MERGE_REPLACE_ALL,
+                            GST_TAG_MERGE_REPLACE,
                             tagName.toUtf8().constData(),
                             tagValue.toString().toUtf8().constData(),
                             NULL);
@@ -739,18 +773,29 @@ void CameraBinSession::setMetaData(const QMap<QByteArray, QVariant> &data)
                     case QVariant::Int:
                     case QVariant::LongLong:
                         gst_tag_setter_add_tags(GST_TAG_SETTER(element),
-                            GST_TAG_MERGE_REPLACE_ALL,
+                            GST_TAG_MERGE_REPLACE,
                             tagName.toUtf8().constData(),
                             tagValue.toInt(),
                             NULL);
                         break;
                     case QVariant::Double:
                         gst_tag_setter_add_tags(GST_TAG_SETTER(element),
-                            GST_TAG_MERGE_REPLACE_ALL,
+                            GST_TAG_MERGE_REPLACE,
                             tagName.toUtf8().constData(),
                             tagValue.toDouble(),
                             NULL);
                         break;
+                    case QVariant::DateTime: {
+                        QDateTime date = tagValue.toDateTime().toLocalTime();
+                        gst_tag_setter_add_tags(GST_TAG_SETTER(element),
+                            GST_TAG_MERGE_REPLACE,
+                            tagName.toUtf8().constData(),
+                            gst_date_time_new_local_time(
+                                        date.date().year(), date.date().month(), date.date().day(),
+                                        date.time().hour(), date.time().minute(), date.time().second()),
+                            NULL);
+                        break;
+                    }
                     default:
                         break;
                 }
@@ -926,6 +971,7 @@ bool CameraBinSession::processBusMessage(const QGstreamerMessage &message)
                             emit stateChanged(m_state = QCamera::UnloadedState);
                         break;
                     case GST_STATE_READY:
+                        setMetaData(m_metaData);
                         if (m_state != QCamera::LoadedState)
                             emit stateChanged(m_state = QCamera::LoadedState);
                         break;
