@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the Qt Mobility Components.
@@ -65,341 +65,9 @@
 #include "sourceresolver.h"
 #include "samplegrabber.h"
 #include "mftvideo.h"
+#include <wmcodecdsp.h>
 
 //#define DEBUG_MEDIAFOUNDATION
-//#define TEST_STREAMING
-
-namespace
-{
-    //MFStream is added for supporting QIODevice type of media source.
-    //It is used to delegate invocations from media foundation(through IMFByteStream) to QIODevice.
-    class MFStream : public QObject, public IMFByteStream
-    {
-        Q_OBJECT
-    public:
-        MFStream(QIODevice *stream, bool ownStream)
-            : m_cRef(1)
-            , m_stream(stream)
-            , m_ownStream(ownStream)
-            , m_currentReadResult(0)
-        {
-            //Move to the thread of the stream object
-            //to make sure invocations on stream
-            //are happened in the same thread of stream object
-            this->moveToThread(stream->thread());
-            connect(stream, SIGNAL(readyRead()), this, SLOT(handleReadyRead()));
-        }
-
-        ~MFStream()
-        {
-            if (m_currentReadResult)
-                m_currentReadResult->Release();
-            if (m_ownStream)
-                m_stream->deleteLater();
-        }
-
-        //from IUnknown
-        STDMETHODIMP QueryInterface(REFIID riid, LPVOID *ppvObject)
-        {
-            if (!ppvObject)
-                return E_POINTER;
-            if (riid == IID_IMFByteStream) {
-                *ppvObject = static_cast<IMFByteStream*>(this);
-            } else if (riid == IID_IUnknown) {
-                *ppvObject = static_cast<IUnknown*>(this);
-            } else {
-                *ppvObject =  NULL;
-                return E_NOINTERFACE;
-            }
-            AddRef();
-            return S_OK;
-        }
-
-        STDMETHODIMP_(ULONG) AddRef(void)
-        {
-            return InterlockedIncrement(&m_cRef);
-        }
-
-        STDMETHODIMP_(ULONG) Release(void)
-        {
-            LONG cRef = InterlockedDecrement(&m_cRef);
-            if (cRef == 0) {
-                this->deleteLater();
-            }
-            return cRef;
-        }
-
-
-        //from IMFByteStream
-        STDMETHODIMP GetCapabilities(DWORD *pdwCapabilities)
-        {
-            if (!pdwCapabilities)
-                return E_INVALIDARG;
-            *pdwCapabilities = MFBYTESTREAM_IS_READABLE;
-            if (!m_stream->isSequential())
-                *pdwCapabilities |= MFBYTESTREAM_IS_SEEKABLE;
-            return S_OK;
-        }
-
-        STDMETHODIMP GetLength(QWORD *pqwLength)
-        {
-            if (!pqwLength)
-                return E_INVALIDARG;
-            QMutexLocker locker(&m_mutex);
-            *pqwLength = QWORD(m_stream->size());
-            return S_OK;
-        }
-
-        STDMETHODIMP SetLength(QWORD)
-        {
-            return E_NOTIMPL;
-        }
-
-        STDMETHODIMP GetCurrentPosition(QWORD *pqwPosition)
-        {
-            if (!pqwPosition)
-                return E_INVALIDARG;
-            QMutexLocker locker(&m_mutex);
-            *pqwPosition = m_stream->pos();
-            return S_OK;
-        }
-
-        STDMETHODIMP SetCurrentPosition(QWORD qwPosition)
-        {
-            QMutexLocker locker(&m_mutex);
-            //SetCurrentPosition may happend during the BeginRead/EndRead pair,
-            //refusing to execute SetCurrentPosition during that time seems to be
-            //the simplest workable solution
-            if (m_currentReadResult)
-                return S_FALSE;
-
-            bool seekOK = m_stream->seek(qint64(qwPosition));
-            if (seekOK)
-                return S_OK;
-            else
-                return S_FALSE;
-        }
-
-        STDMETHODIMP IsEndOfStream(BOOL *pfEndOfStream)
-        {
-            if (!pfEndOfStream)
-                return E_INVALIDARG;
-            QMutexLocker locker(&m_mutex);
-            *pfEndOfStream = m_stream->atEnd() ? TRUE : FALSE;
-            return S_OK;
-        }
-
-        STDMETHODIMP Read(BYTE *pb, ULONG cb, ULONG *pcbRead)
-        {
-            QMutexLocker locker(&m_mutex);
-            qint64 read = m_stream->read((char*)(pb), qint64(cb));
-            if (pcbRead)
-                *pcbRead = ULONG(read);
-            return S_OK;
-        }
-
-        STDMETHODIMP BeginRead(BYTE *pb, ULONG cb, IMFAsyncCallback *pCallback,
-                               IUnknown *punkState)
-        {
-            if (!pCallback || !pb)
-                return E_INVALIDARG;
-
-            Q_ASSERT(m_currentReadResult == NULL);
-
-            AsyncReadState *state = new (std::nothrow) AsyncReadState(pb, cb);
-            if (state == NULL)
-                return E_OUTOFMEMORY;
-
-            HRESULT hr = MFCreateAsyncResult(state, pCallback, punkState, &m_currentReadResult);
-            state->Release();
-            if (FAILED(hr))
-                return hr;
-
-            QCoreApplication::postEvent(this, new QEvent(QEvent::User));
-            return hr;
-        }
-
-        STDMETHODIMP EndRead(IMFAsyncResult* pResult, ULONG *pcbRead)
-        {
-            if (!pcbRead)
-                return E_INVALIDARG;
-            IUnknown *pUnk;
-            pResult->GetObject(&pUnk);
-            AsyncReadState *state = static_cast<AsyncReadState*>(pUnk);
-            *pcbRead = state->bytesRead();
-            pUnk->Release();
-
-            m_currentReadResult->Release();
-            m_currentReadResult = NULL;
-
-            return S_OK;
-        }
-
-        STDMETHODIMP Write(const BYTE *, ULONG, ULONG *)
-        {
-            return E_NOTIMPL;
-        }
-
-        STDMETHODIMP BeginWrite(const BYTE *, ULONG ,
-                                IMFAsyncCallback *,
-                                IUnknown *)
-        {
-            return E_NOTIMPL;
-        }
-
-        STDMETHODIMP EndWrite(IMFAsyncResult *,
-                              ULONG *)
-        {
-            return E_NOTIMPL;
-        }
-
-        STDMETHODIMP Seek(
-            MFBYTESTREAM_SEEK_ORIGIN SeekOrigin,
-            LONGLONG llSeekOffset,
-            DWORD,
-            QWORD *pqwCurrentPosition)
-        {
-            QMutexLocker locker(&m_mutex);
-            if (m_currentReadResult)
-                return S_FALSE;
-
-            qint64 pos = qint64(llSeekOffset);
-            switch (SeekOrigin) {
-            case msoCurrent:
-                pos += m_stream->pos();
-                break;
-            }
-            bool seekOK = m_stream->seek(pos);
-            if (*pqwCurrentPosition)
-                *pqwCurrentPosition = pos;
-            if (seekOK)
-                return S_OK;
-            else
-                return S_FALSE;
-        }
-
-        STDMETHODIMP Flush()
-        {
-            return E_NOTIMPL;
-        }
-
-        STDMETHODIMP Close()
-        {
-            QMutexLocker locker(&m_mutex);
-            if (m_ownStream)
-                m_stream->close();
-            return S_OK;
-        }
-
-    private:
-        //AsyncReadState is a helper class used in BeginRead for asynchronous operation
-        //to record some BeginRead parameters, so these parameters could be
-        //used later when actually executing the read operation in another thread.
-        class AsyncReadState : public IUnknown
-        {
-        public:
-            AsyncReadState(BYTE *pb, ULONG cb)
-                : m_cRef(1)
-                , m_pb(pb)
-                , m_cb(cb)
-                , m_cbRead(0)
-            {
-            }
-
-            //from IUnknown
-            STDMETHODIMP QueryInterface(REFIID riid, LPVOID *ppvObject)
-            {
-                if (!ppvObject)
-                    return E_POINTER;
-
-                if (riid == IID_IUnknown) {
-                    *ppvObject = static_cast<IUnknown*>(this);
-                } else {
-                    *ppvObject =  NULL;
-                    return E_NOINTERFACE;
-                }
-                AddRef();
-                return S_OK;
-            }
-
-            STDMETHODIMP_(ULONG) AddRef(void)
-            {
-                return InterlockedIncrement(&m_cRef);
-            }
-
-            STDMETHODIMP_(ULONG) Release(void)
-            {
-                LONG cRef = InterlockedDecrement(&m_cRef);
-                if (cRef == 0)
-                    delete this;
-                // For thread safety, return a temporary variable.
-                return cRef;
-            }
-
-            BYTE* pb() const { return m_pb; }
-            ULONG cb() const { return m_cb; }
-            ULONG bytesRead() const { return m_cbRead; }
-
-            void setBytesRead(ULONG cbRead) { m_cbRead = cbRead; }
-
-        private:
-            long m_cRef;
-            BYTE *m_pb;
-            ULONG m_cb;
-            ULONG m_cbRead;
-        };
-
-        long m_cRef;
-        QIODevice *m_stream;
-        bool m_ownStream;
-        DWORD m_workQueueId;
-        QMutex m_mutex;
-
-        void doRead()
-        {
-            bool readDone = true;
-            IUnknown *pUnk = NULL;
-            HRESULT    hr = m_currentReadResult->GetObject(&pUnk);
-            if (SUCCEEDED(hr)) {
-                //do actual read
-                AsyncReadState *state =  static_cast<AsyncReadState*>(pUnk);
-                ULONG cbRead;
-                Read(state->pb(), state->cb() - state->bytesRead(), &cbRead);
-                pUnk->Release();
-
-                state->setBytesRead(cbRead + state->bytesRead());
-                if (state->cb() > state->bytesRead() && !m_stream->atEnd()) {
-                    readDone = false;
-                }
-            }
-
-            if (readDone) {
-                //now inform the original caller
-                m_currentReadResult->SetStatus(hr);
-                MFInvokeCallback(m_currentReadResult);
-            }
-        }
-
-
-    private Q_SLOTS:
-        void handleReadyRead()
-        {
-            doRead();
-        }
-
-    protected:
-        void customEvent(QEvent *event)
-        {
-            if (event->type() != QEvent::User) {
-                QObject::customEvent(event);
-                return;
-            }
-            doRead();
-        }
-        IMFAsyncResult *m_currentReadResult;
-    };
-}
-
 
 MFPlayerSession::MFPlayerSession(MFPlayerService *playerService)
     : m_playerService(playerService)
@@ -410,6 +78,8 @@ MFPlayerSession::MFPlayerSession(MFPlayerService *playerService)
     , m_rateSupport(0)
     , m_volumeControl(0)
     , m_netsourceStatistics(0)
+    , m_duration(0)
+    , m_sourceResolver(0)
     , m_hCloseEvent(0)
     , m_closing(false)
     , m_pendingRate(1)
@@ -535,7 +205,7 @@ void MFPlayerSession::load(const QMediaContent &media, QIODevice *stream)
     clear();
     QMediaResourceList resources = media.resources();
 
-    if (m_status == QMediaPlayer::LoadingMedia)
+    if (m_status == QMediaPlayer::LoadingMedia && m_sourceResolver)
         m_sourceResolver->cancel();
 
     if (resources.isEmpty() && !stream) {
@@ -580,7 +250,7 @@ void MFPlayerSession::handleSourceError(long hr)
 
 void MFPlayerSession::handleMediaSourceReady()
 {
-    if (QMediaPlayer::LoadingMedia != m_status)
+    if (QMediaPlayer::LoadingMedia != m_status || !m_sourceResolver)
         return;
 #ifdef DEBUG_MEDIAFOUNDATION
     qDebug() << "handleMediaSourceReady";
@@ -1004,8 +674,16 @@ IMFTopology *MFPlayerSession::insertMFT(IMFTopology *topology, TOPOID outputNode
         if (FAILED(MFCreateTopoLoader(&topoLoader)))
             break;
 
-        if (FAILED(topoLoader->Load(topology, &resolvedTopology, NULL)))
-            break;
+        if (FAILED(topoLoader->Load(topology, &resolvedTopology, NULL))) {
+            // Topology could not be resolved, adding ourselves a color converter
+            // to the topology might solve the problem
+            insertColorConverter(topology, outputNodeId);
+            if (FAILED(topoLoader->Load(topology, &resolvedTopology, NULL)))
+                break;
+        }
+
+        if (insertResizer(resolvedTopology))
+            isNewTopology = true;
 
         // Get all output nodes and search for video output node.
         if (FAILED(resolvedTopology->GetOutputNodeCollection(&outputNodes)))
@@ -1022,6 +700,7 @@ IMFTopology *MFPlayerSession::insertMFT(IMFTopology *topology, TOPOID outputNode
             IMFMediaTypeHandler *videoSink = 0;
             IMFTopologyNode *inputNode = 0;
             IMFTopologyNode *mftNode = 0;
+            bool mftAdded = false;
 
             do {
                 if (FAILED(outputNodes->GetElement(n, &element)))
@@ -1074,6 +753,7 @@ IMFTopology *MFPlayerSession::insertMFT(IMFTopology *topology, TOPOID outputNode
                 if (FAILED(mftNode->ConnectOutput(0, node, 0)))
                     break;
 
+                mftAdded = true;
                 isNewTopology = true;
             } while (false);
 
@@ -1090,7 +770,7 @@ IMFTopology *MFPlayerSession::insertMFT(IMFTopology *topology, TOPOID outputNode
             if (outputObject)
                 outputObject->Release();
 
-            if (isNewTopology)
+            if (mftAdded)
                 break;
         }
     } while (false);
@@ -1112,6 +792,177 @@ IMFTopology *MFPlayerSession::insertMFT(IMFTopology *topology, TOPOID outputNode
     return topology;
 }
 
+// This method checks if the topology contains a color converter transform (CColorConvertDMO),
+// if it does it inserts a resizer transform (CResizerDMO) to handle dynamic frame size change
+// of the video stream.
+// Returns true if it inserted a resizer
+bool MFPlayerSession::insertResizer(IMFTopology *topology)
+{
+    bool inserted = false;
+    WORD elementCount = 0;
+    IMFTopologyNode *node = 0;
+    IUnknown *object = 0;
+    IWMColorConvProps *colorConv = 0;
+    IMFTransform *resizer = 0;
+    IMFTopologyNode *resizerNode = 0;
+    IMFTopologyNode *inputNode = 0;
+
+    HRESULT hr = topology->GetNodeCount(&elementCount);
+    if (FAILED(hr))
+        return false;
+
+    for (WORD i = 0; i < elementCount; ++i) {
+        if (node) {
+            node->Release();
+            node = 0;
+        }
+        if (object) {
+            object->Release();
+            object = 0;
+        }
+
+        if (FAILED(topology->GetNode(i, &node)))
+            break;
+
+        MF_TOPOLOGY_TYPE nodeType;
+        if (FAILED(node->GetNodeType(&nodeType)))
+            break;
+
+        if (nodeType != MF_TOPOLOGY_TRANSFORM_NODE)
+            continue;
+
+        if (FAILED(node->GetObject(&object)))
+            break;
+
+        if (FAILED(object->QueryInterface(&colorConv)))
+            continue;
+
+        if (FAILED(CoCreateInstance(CLSID_CResizerDMO, NULL, CLSCTX_INPROC_SERVER, IID_IMFTransform, (void**)&resizer)))
+            break;
+
+        if (FAILED(MFCreateTopologyNode(MF_TOPOLOGY_TRANSFORM_NODE, &resizerNode)))
+            break;
+
+        if (FAILED(resizerNode->SetObject(resizer)))
+            break;
+
+        if (FAILED(topology->AddNode(resizerNode)))
+            break;
+
+        DWORD outputIndex = 0;
+        if (FAILED(node->GetInput(0, &inputNode, &outputIndex))) {
+            topology->RemoveNode(resizerNode);
+            break;
+        }
+
+        if (FAILED(inputNode->ConnectOutput(0, resizerNode, 0))) {
+            topology->RemoveNode(resizerNode);
+            break;
+        }
+
+        if (FAILED(resizerNode->ConnectOutput(0, node, 0))) {
+            inputNode->ConnectOutput(0, node, 0);
+            topology->RemoveNode(resizerNode);
+            break;
+        }
+
+        inserted = true;
+        break;
+    }
+
+    if (node)
+        node->Release();
+    if (object)
+        object->Release();
+    if (colorConv)
+        colorConv->Release();
+    if (resizer)
+        resizer->Release();
+    if (resizerNode)
+        resizerNode->Release();
+    if (inputNode)
+        inputNode->Release();
+
+    return inserted;
+}
+
+// This method inserts a color converter (CColorConvertDMO) in the topology,
+// typically to convert to RGB format.
+// Usually this converter is automatically inserted when the topology is resolved but
+// for some reason it fails to do so in some cases, we then do it ourselves.
+void MFPlayerSession::insertColorConverter(IMFTopology *topology, TOPOID outputNodeId)
+{
+    IMFCollection *outputNodes = 0;
+
+    if (FAILED(topology->GetOutputNodeCollection(&outputNodes)))
+        return;
+
+    DWORD elementCount = 0;
+    if (FAILED(outputNodes->GetElementCount(&elementCount)))
+        goto done;
+
+    for (DWORD n = 0; n < elementCount; n++) {
+        IUnknown *element = 0;
+        IMFTopologyNode *node = 0;
+        IMFTopologyNode *inputNode = 0;
+        IMFTopologyNode *mftNode = 0;
+        IMFTransform *converter = 0;
+
+        do {
+            if (FAILED(outputNodes->GetElement(n, &element)))
+                break;
+
+            if (FAILED(element->QueryInterface(IID_IMFTopologyNode, (void**)&node)))
+                break;
+
+            TOPOID id;
+            if (FAILED(node->GetTopoNodeID(&id)))
+                break;
+
+            if (id != outputNodeId)
+                break;
+
+            DWORD outputIndex = 0;
+            if (FAILED(node->GetInput(0, &inputNode, &outputIndex)))
+                break;
+
+            if (FAILED(MFCreateTopologyNode(MF_TOPOLOGY_TRANSFORM_NODE, &mftNode)))
+                break;
+
+            if (FAILED(CoCreateInstance(CLSID_CColorConvertDMO, NULL, CLSCTX_INPROC_SERVER, IID_IMFTransform, (void**)&converter)))
+                break;
+
+            if (FAILED(mftNode->SetObject(converter)))
+                break;
+
+            if (FAILED(topology->AddNode(mftNode)))
+                break;
+
+            if (FAILED(inputNode->ConnectOutput(0, mftNode, 0)))
+                break;
+
+            if (FAILED(mftNode->ConnectOutput(0, node, 0)))
+                break;
+
+        } while (false);
+
+        if (mftNode)
+            mftNode->Release();
+        if (inputNode)
+            inputNode->Release();
+        if (node)
+            node->Release();
+        if (element)
+            element->Release();
+        if (converter)
+            converter->Release();
+    }
+
+done:
+    if (outputNodes)
+        outputNodes->Release();
+}
+
 void MFPlayerSession::stop(bool immediate)
 {
 #ifdef DEBUG_MEDIAFOUNDATION
@@ -1141,14 +992,8 @@ void MFPlayerSession::stop(bool immediate)
 
 void MFPlayerSession::start()
 {
-    switch (m_status) {
-    case QMediaPlayer::EndOfMedia:
-        m_varStart.hVal.QuadPart = 0;
-        //since it must be loaded already, just fallthrough
-    case QMediaPlayer::LoadedMedia:
-        changeStatus(QMediaPlayer::BufferedMedia);
-        return;
-    }
+    if (m_status == QMediaPlayer::EndOfMedia)
+        m_varStart.hVal.QuadPart = 0; // restart from the beginning
 
 #ifdef DEBUG_MEDIAFOUNDATION
     qDebug() << "start";
@@ -1282,6 +1127,9 @@ void MFPlayerSession::setPositionInternal(qint64 position, Command requestCmd)
     if (m_state.command == CmdStop && requestCmd != CmdSeekResume) {
         m_varStart.vt = VT_I8;
         m_varStart.hVal.QuadPart = LONGLONG(position * 10000);
+        // Even though the position is not actually set on the session yet,
+        // report it to have changed anyway for UI controls to be updated
+        emit positionChanged(this->position());
         return;
     }
 
@@ -1376,29 +1224,42 @@ void MFPlayerSession::commitRateChange(qreal rate, BOOL isThin)
     // Negative <-> zero:       Stopped
     // Postive <-> zero:        Paused or stopped
     if ((rate > 0 && m_state.rate <= 0) || (rate < 0 && m_state.rate >= 0)) {
-        // Transition to stopped.
         if (cmdNow == CmdStart) {
             // Get the current clock position. This will be the restart time.
             m_presentationClock->GetCorrelatedTime(0, &hnsClockTime, &hnsSystemTime);
             Q_ASSERT(hnsSystemTime != 0);
 
-            // Stop and set the rate
-            stop();
+            m_request.setCommand(rate < 0 || m_state.rate < 0 ? CmdSeekResume : CmdStart);
 
-            //Cache Request: Restart from stop.
-            m_request.setCommand(CmdSeekResume);
+            // We need to stop only when dealing with negative rates
+            if (rate >= 0 && m_state.rate >= 0)
+                pause();
+            else
+                stop();
+
+            // If we deal with negative rates, we stopped the session and consequently
+            // reset the position to zero. We then need to resume to the current position.
             m_request.start = hnsClockTime / 10000;
         } else if (cmdNow == CmdPause) {
-            // The current state is paused.
-            // For this rate change, the session must be stopped. However, the
-            // session cannot transition back from stopped to paused.
-            // Therefore, this rate transition is not supported while paused.
             if (rate < 0 || m_state.rate < 0) {
+                // The current state is paused.
+                // For this rate change, the session must be stopped. However, the
+                // session cannot transition back from stopped to paused.
+                // Therefore, this rate transition is not supported while paused.
                 qWarning() << "Unable to change rate from positive to negative or vice versa in paused state";
                 return;
             }
+
+            // This happens when resuming playback after scrubbing in pause mode.
+            // This transition requires the session to be paused. Even though our
+            // internal state is set to paused, the session might not be so we need
+            // to enforce it
+            if (rate > 0 && m_state.rate == 0) {
+                m_state.setCommand(CmdNone);
+                pause();
+            }
         }
-    } else if (rate == 0 && m_state.rate != 0) {
+    } else if (rate == 0 && m_state.rate > 0) {
         if (cmdNow != CmdPause) {
             // Transition to paused.
             // This transisition requires the paused state.
@@ -1408,6 +1269,16 @@ void MFPlayerSession::commitRateChange(qreal rate, BOOL isThin)
             // Request: Switch back to current state.
             m_request.setCommand(cmdNow);
         }
+    } else if (rate == 0 && m_state.rate < 0) {
+        // Changing rate from negative to zero requires to stop the session
+        m_presentationClock->GetCorrelatedTime(0, &hnsClockTime, &hnsSystemTime);
+
+        m_request.setCommand(CmdSeekResume);
+
+        stop();
+
+        // Resume to the current position (stop() will reset the position to 0)
+        m_request.start = hnsClockTime / 10000;
     }
 
     // Set the rate.
@@ -1584,7 +1455,7 @@ void MFPlayerSession::handleSessionEvent(IMFMediaEvent *sessionEvent)
 {
     HRESULT hrStatus = S_OK;
     HRESULT hr = sessionEvent->GetStatus(&hrStatus);
-    if (FAILED(hr)) {
+    if (FAILED(hr) || !m_session) {
         sessionEvent->Release();
         return;
     }
@@ -1634,8 +1505,13 @@ void MFPlayerSession::handleSessionEvent(IMFMediaEvent *sessionEvent)
             updatePendingCommands(CmdStart);
         break;
     case MESessionStarted:
-        if (!m_scrubbing)
-            updatePendingCommands(CmdStart);
+        if (m_status == QMediaPlayer::EndOfMedia
+                || m_status == QMediaPlayer::LoadedMedia) {
+            // If the session started, then enough data is buffered to play
+            changeStatus(QMediaPlayer::BufferedMedia);
+        }
+
+        updatePendingCommands(CmdStart);
 #ifndef Q_WS_SIMULATOR
         // playback started, we can now set again the procAmpValues if they have been
         // changed previously (these are lost when loading a new media)
@@ -1649,10 +1525,10 @@ void MFPlayerSession::handleSessionEvent(IMFMediaEvent *sessionEvent)
             m_varStart.vt = VT_I8;
             m_varStart.hVal.QuadPart = 0;
 
-            //only change to loadedMedia when not loading a new media source
-            if (m_status != QMediaPlayer::LoadingMedia) {
+            // Reset to Loaded status unless we are loading a new media
+            // or changing the playback rate to negative values (stop required)
+            if (m_status != QMediaPlayer::LoadingMedia && m_request.command != CmdSeekResume)
                 changeStatus(QMediaPlayer::LoadedMedia);
-            }
         }
         updatePendingCommands(CmdStop);
         break;
@@ -1675,11 +1551,22 @@ void MFPlayerSession::handleSessionEvent(IMFMediaEvent *sessionEvent)
             emit error(QMediaPlayer::FormatError, tr("Unsupported media, a codec is missing."), true);
         } else {
             if (m_audioSampleGrabberNode) {
-                IMFMediaType *mediaType = 0;
-                hr = MFGetTopoNodeCurrentType(m_audioSampleGrabberNode, 0, FALSE, &mediaType);
-                if (SUCCEEDED(hr)) {
-                    m_audioSampleGrabber->setFormat(audioFormatForMFMediaType(mediaType));
-                    mediaType->Release();
+                IUnknown *obj = 0;
+                if (SUCCEEDED(m_audioSampleGrabberNode->GetObject(&obj))) {
+                    IMFStreamSink *streamSink = 0;
+                    if (SUCCEEDED(obj->QueryInterface(IID_PPV_ARGS(&streamSink)))) {
+                        IMFMediaTypeHandler *typeHandler = 0;
+                        if (SUCCEEDED(streamSink->GetMediaTypeHandler((&typeHandler)))) {
+                            IMFMediaType *mediaType = 0;
+                            if (SUCCEEDED(typeHandler->GetCurrentMediaType(&mediaType))) {
+                                m_audioSampleGrabber->setFormat(audioFormatForMFMediaType(mediaType));
+                                mediaType->Release();
+                            }
+                            typeHandler->Release();
+                        }
+                        streamSink->Release();
+                    }
+                    obj->Release();
                 }
             }
 
@@ -1716,19 +1603,19 @@ void MFPlayerSession::handleSessionEvent(IMFMediaEvent *sessionEvent)
         changeStatus(QMediaPlayer::BufferedMedia);
         emit bufferStatusChanged(bufferStatus());
         break;
-    case MEEndOfPresentation:
-        stop();
-        changeStatus(QMediaPlayer::EndOfMedia);
-        m_varStart.vt = VT_I8;
-        //keep reporting the final position after end of media
-        m_varStart.hVal.QuadPart = m_duration;
-        break;
     case MESessionEnded:
         m_pendingState = NoPending;
         m_state.command = CmdStop;
         m_state.prevCmd = CmdNone;
         m_request.command = CmdNone;
         m_request.prevCmd = CmdNone;
+
+        m_varStart.vt = VT_I8;
+        //keep reporting the final position after end of media
+        m_varStart.hVal.QuadPart = m_duration;
+        emit positionChanged(position());
+
+        changeStatus(QMediaPlayer::EndOfMedia);
         break;
     case MEEndOfPresentationSegment:
         break;
@@ -1781,6 +1668,8 @@ void MFPlayerSession::handleSessionEvent(IMFMediaEvent *sessionEvent)
             }
         }
         break;
+    default:
+        break;
     }
 
     sessionEvent->Release();
@@ -1795,15 +1684,7 @@ void MFPlayerSession::updatePendingCommands(Command command)
     // The current pending command has completed.
     if (m_pendingState == SeekPending && m_state.prevCmd == CmdPause) {
         m_pendingState = NoPending;
-        //if we have pending seek request,
-        //then we just keep current state to paused and continue the seek request,
-        //otherwise we will restore to pause state
-        if (m_request.command == CmdSeek) {
-            m_state.setCommand(CmdPause);
-        } else {
-            pause();
-            return;
-        }
+        m_state.setCommand(CmdPause);
     }
 
     m_pendingState = NoPending;
