@@ -569,6 +569,8 @@ void tst_QPainterVideoSurface::shaderType()
 {
     QPainterVideoSurface surface;
     QGLWidget widget;
+    widget.show();
+    QTest::qWaitForWindowShown(&widget);
     widget.makeCurrent();
 
     QCOMPARE(surface.shaderType(), QPainterVideoSurface::NoShaders);
@@ -659,6 +661,8 @@ void tst_QPainterVideoSurface::shaderTypeStarted()
     QFETCH(QPainterVideoSurface::ShaderType, shaderType);
 
     QGLWidget widget;
+    widget.show();
+    QTest::qWaitForWindowShown(&widget);
     widget.makeCurrent();
 
     QPainterVideoSurface surface;
@@ -902,6 +906,8 @@ void tst_QPainterVideoSurface::shaderSupportedFormat()
     QFETCH(bool, supportedFormat);
 
     QGLWidget widget;
+    widget.show();
+    QTest::qWaitForWindowShown(&widget);
     widget.makeCurrent();
 
     QPainterVideoSurface surface;
@@ -1017,6 +1023,8 @@ void tst_QPainterVideoSurface::shaderPresent()
     QFETCH(int, bytesPerLineB);
 
     QGLWidget widget;
+    widget.show();
+    QTest::qWaitForWindowShown(&widget);
     widget.makeCurrent();
 
     QPainterVideoSurface surface;
@@ -1039,12 +1047,6 @@ void tst_QPainterVideoSurface::shaderPresent()
 
     QVideoSurfaceFormat formatA(frameSizeA, pixelFormatA);
 
-#if defined(Q_OS_LINUX) && !defined(UBUNTU_PRECISE_PANGOLIN)
-    QEXPECT_FAIL("ARBfp: rgb32 -> argb32", "QTBUG-26320 - Failing for linux versions", Abort);
-    QEXPECT_FAIL("ARBfp: rgb32 -> rgb565", "QTBUG-26320 - Failing for linux versions", Abort);
-    QEXPECT_FAIL("ARBfp: rgb32 -> yuv420p", "QTBUG-26320 - Failing for linux versions", Abort);
-    QEXPECT_FAIL("ARBfp: yv12 -> rgb32", "QTBUG-26320 - Failing for linux versions", Abort);
-#endif
     QVERIFY(surface.start(formatA));
     QCOMPARE(surface.isActive(), true);
     QCOMPARE(surface.isReady(), true);
@@ -1152,6 +1154,8 @@ void tst_QPainterVideoSurface::shaderPresentOpaqueFrame()
     QFETCH(QPainterVideoSurface::ShaderType, shaderType);
 
     QGLWidget widget;
+    widget.show();
+    QTest::qWaitForWindowShown(&widget);
     widget.makeCurrent();
 
     QPainterVideoSurface surface;
@@ -1199,6 +1203,8 @@ void tst_QPainterVideoSurface::shaderPresentGLFrame()
     QFETCH(QPainterVideoSurface::ShaderType, shaderType);
 
     QGLWidget widget;
+    widget.show();
+    QTest::qWaitForWindowShown(&widget);
     widget.makeCurrent();
 
     QPainterVideoSurface surface;
